
#!/usr/bin/env python
# -*- coding: UTF-8 -*-

# pylint:disable=bad-whitespace
# pylint:disable=line-too-long
# pylint:disable=too-many-lines
# pylint:disable=invalid-name

# #########################################################
#
#       ************** !! WARNING !! ***************
#       ******* THIS FILE WAS AUTO-GENERATED *******
#       ********* DO NOT MODIFY THIS FILE **********
#
# #########################################################

wordnet_terms_t_provenance = {
    'action': ['router.py',
               'plac_core.py',
               'csv2py_orchestrator.py',
               'wordnet2py.py',
               'csv_list_writer.py',
               'common_utils.py'],
    'source': 'resources/data/csv/wordnet.csv',
    'time': '2022-05-17 17:00:36.230957'}

wordnet_terms_t = [
    'ta',
    'taal',
    'tab',
    'tabanidae',
    'tabard',
    'tabasco',
    'tabbouleh',
    'tabby',
    'tabernacle',
    'tabernacles',
    'tabernaemontana',
    'tabes',
    'tabi',
    'tabis',
    'tablature',
    'table',
    'tableau',
    'tablecloth',
    'tablefork',
    'tableland',
    'tablemate',
    'tables',
    'tablespoon',
    'tablespoonful',
    'tablespoons',
    'tablet',
    'tabletop',
    'tabletops',
    'tablets',
    'tableware',
    'tabloid',
    'tabloids',
    'taboo',
    'tabooli',
    'tabor',
    'tabora',
    'taboret',
    'tabour',
    'tabouret',
    'tabriz',
    'tabs',
    'tabu',
    'tabuk',
    'tabular',
    'tabularise',
    'tabularize',
    'tabulate',
    'tabulating',
    'tabulation',
    'tabulator',
    'tabun',
    'tacamahac',
    'tacca',
    'taccaceae',
    'tach',
    'tacheometer',
    'tachinidae',
    'tachistoscope',
    'tachogram',
    'tachograph',
    'tachometer',
    'tachycardia',
    'tachyglossidae',
    'tachyglossus',
    'tachygraphy',
    'tachylite',
    'tachymeter',
    'tachypleus',
    'tacit',
    'taciturn',
    'taciturnity',
    'tacitus',
    'tack',
    'tacked',
    'tacker',
    'tackiness',
    'tacking',
    'tackle',
    'tackled',
    'tackler',
    'tackles',
    'tackling',
    'tacks',
    'tacky',
    'taco',
    'tacoma',
    'taconite',
    'tacos',
    'tact',
    'tactful',
    'tactfully',
    'tactfulness',
    'tactic',
    'tactical',
    'tactician',
    'tactics',
    'tactile',
    'tactility',
    'tactless',
    'tactlessness',
    'tactual',
    'tad',
    'tadalafil',
    'tadarida',
    'tadjik',
    'tadorna',
    'tadpole',
    'tadpoles',
    'tadzhik',
    'tadzhikistan',
    'taegu',
    'taekwondo',
    'tael',
    'taenia',
    'taeniidae',
    'tafari',
    'taffeta',
    'taffrail',
    'taffy',
    'taft',
    'tag',
    'tagalog',
    'tagalong',
    'tagamet',
    'tagasaste',
    'tagetes',
    'tageteste',
    'tagged',
    'tagger',
    'tagging',
    'tagliatelle',
    'tagore',
    'tags',
    'taguan',
    'tagus',
    'tahini',
    'tahiti',
    'tahitian',
    'tai',
    'taichi',
    'taichichuan',
    'taichung',
    'taif',
    'tail',
    'tailback',
    'tailboard',
    'tailcoat',
    'tailcoats',
    'tailed',
    'tailfin',
    'tailflower',
    'tailgate',
    'tailgater',
    'tailing',
    'tailless',
    'taillight',
    'taillike',
    'tailor',
    'tailorbird',
    'tailorbirds',
    'tailored',
    'tailoring',
    'tailors',
    'tailpiece',
    'tailpipe',
    'tailplane',
    'tailrace',
    'tails',
    'tailspin',
    'tailstock',
    'tailwind',
    'tailwort',
    'taimyr',
    'taint',
    'tainted',
    'taints',
    'taipan',
    'taipans',
    'taipeh',
    'taipei',
    'taira',
    'taiwan',
    'taiwanese',
    'taiyuan',
    'taj',
    'tajik',
    'tajiki',
    'tajikistan',
    'tajikistani',
    'taka',
    'takahe',
    'takakkaw',
    'take',
    'takeaway',
    'takedown',
    'takelma',
    'taken',
    'takeoff',
    'takeoffs',
    'takeout',
    'takeover',
    'takeovers',
    'taker',
    'takes',
    'takilman',
    'takin',
    'taking',
    'takings',
    'tala',
    'talapoin',
    'talaria',
    'talbot',
    'talc',
    'talcum',
    'tale',
    'taleban',
    'talebearer',
    'talent',
    'talented',
    'talentless',
    'talentlessness',
    'talents',
    'tales',
    'taleteller',
    'taliban',
    'talien',
    'talinum',
    'taliped',
    'talipes',
    'talipot',
    'talisman',
    'talismanic',
    'talismans',
    'talk',
    'talkative',
    'talkativeness',
    'talked',
    'talker',
    'talkie',
    'talking',
    'talks',
    'talky',
    'tall',
    'tallahassee',
    'tallapoosa',
    'tallboy',
    'tallchief',
    'taller',
    'tallest',
    'talleyrand',
    'tallgrass',
    'tallin',
    'tallinn',
    'tallis',
    'tallish',
    'tallith',
    'tallness',
    'tallow',
    'tally',
    'tallyman',
    'talmud',
    'talmudic',
    'talon',
    'taloned',
    'talons',
    'talpidae',
    'talus',
    'taluses',
    'talwin',
    'tam',
    'tamable',
    'tamal',
    'tamale',
    'tamandu',
    'tamandua',
    'tamanoir',
    'tamarack',
    'tamarao',
    'tamarau',
    'tamaricaceae',
    'tamarillo',
    'tamarin',
    'tamarind',
    'tamarindo',
    'tamarindus',
    'tamarins',
    'tamarisk',
    'tamarix',
    'tambac',
    'tambala',
    'tambocor',
    'tambour',
    'tambourine',
    'tamburlaine',
    'tame',
    'tameable',
    'tamed',
    'tamely',
    'tameness',
    'tamer',
    'tamerlane',
    'tames',
    'tamest',
    'tamias',
    'tamiasciurus',
    'tamil',
    'tamm',
    'tammany',
    'tammerfors',
    'tammuz',
    'tammy',
    'tamoxifen',
    'tamp',
    'tampa',
    'tampax',
    'tamper',
    'tampere',
    'tampered',
    'tampering',
    'tampico',
    'tamping',
    'tampion',
    'tampon',
    'tamponade',
    'tamponage',
    'tampons',
    'tamus',
    'tan',
    'tanacetum',
    'tanach',
    'tanager',
    'tanagers',
    'tanakh',
    'tanbark',
    'tancred',
    'tandearil',
    'tandem',
    'tandoor',
    'tandy',
    'tanekaha',
    'taney',
    'tang',
    'tanga',
    'tanganyika',
    'tange',
    'tangelo',
    'tangency',
    'tangent',
    'tangential',
    'tangerine',
    'tangerines',
    'tangibility',
    'tangible',
    'tangibleness',
    'tangier',
    'tangiers',
    'tanginess',
    'tangle',
    'tanglebush',
    'tangled',
    'tangles',
    'tangling',
    'tango',
    'tangor',
    'tangram',
    'tangshan',
    'tanguy',
    'tangy',
    'tank',
    'tanka',
    'tankage',
    'tankard',
    'tanker',
    'tankers',
    'tankful',
    'tanks',
    'tanned',
    'tannenberg',
    'tanner',
    'tannery',
    'tannia',
    'tannic',
    'tannin',
    'tanning',
    'tannins',
    'tannish',
    'tannoy',
    'tanoan',
    'tans',
    'tansy',
    'tantalise',
    'tantaliser',
    'tantalising',
    'tantalite',
    'tantalization',
    'tantalize',
    'tantalizer',
    'tantalizing',
    'tantalum',
    'tantalus',
    'tantamount',
    'tantilla',
    'tantra',
    'tantric',
    'tantrik',
    'tantrism',
    'tantrist',
    'tantrum',
    'tantrums',
    'tanzania',
    'tanzanian',
    'tanzim',
    'tao',
    'taoiseach',
    'taoism',
    'taoist',
    'taos',
    'tap',
    'tapa',
    'tapdance',
    'tapdances',
    'tape',
    'taped',
    'tapeline',
    'tapenade',
    'taper',
    'tapered',
    'tapering',
    'tapers',
    'tapes',
    'tapestried',
    'tapestry',
    'tapeworm',
    'tapeworms',
    'taphephobia',
    'taphouse',
    'taping',
    'tapioca',
    'tapir',
    'tapiridae',
    'tapirs',
    'tapirus',
    'tapis',
    'tapotement',
    'tappa',
    'tappan',
    'tapped',
    'tapper',
    'tappers',
    'tappet',
    'tapping',
    'tappings',
    'taproom',
    'taproot',
    'taproots',
    'taps',
    'tapster',
    'tar',
    'tara',
    'tarabulus',
    'taracahitian',
    'taradiddle',
    'tarahumara',
    'taraktagenos',
    'taraktogenos',
    'tarandus',
    'tarantella',
    'tarantelle',
    'tarantino',
    'tarantism',
    'tarantula',
    'tarantulas',
    'tarawa',
    'taraxacum',
    'tarbell',
    'tarboosh',
    'tardigrada',
    'tardigrade',
    'tardiness',
    'tardive',
    'tardy',
    'tare',
    'target',
    'targeted',
    'targeting',
    'targets',
    'tarheel',
    'taricha',
    'tariff',
    'tariffs',
    'tarkovsky',
    'tarmac',
    'tarmacadam',
    'tarn',
    'tarnish',
    'tarnished',
    'tarnishes',
    'tarnishing',
    'taro',
    'tarot',
    'tarp',
    'tarpan',
    'tarpaulin',
    'tarpon',
    'tarpons',
    'tarquin',
    'tarquinius',
    'tarradiddle',
    'tarragon',
    'tarred',
    'tarriance',
    'tarrietia',
    'tarry',
    'tarrying',
    'tars',
    'tarsal',
    'tarsier',
    'tarsiers',
    'tarsiidae',
    'tarsioidea',
    'tarsitis',
    'tarsius',
    'tarsus',
    'tart',
    'tartan',
    'tartar',
    'tartarean',
    'tartaric',
    'tartars',
    'tartarus',
    'tartary',
    'tarted',
    'tartlet',
    'tartness',
    'tartrate',
    'tarts',
    'tartu',
    'tartufe',
    'tartuffe',
    'tarweed',
    'tarwood',
    'tarzan',
    'tashkent',
    'tashmit',
    'tashmitum',
    'task',
    'tasked',
    'taskent',
    'tasking',
    'taskmaster',
    'taskmistress',
    'tasks',
    'tasman',
    'tasmania',
    'tasmanian',
    'tasse',
    'tassel',
    'tasseled',
    'tasselled',
    'tassels',
    'tasset',
    'tasso',
    'taste',
    'tastebud',
    'tasted',
    'tasteful',
    'tastefulness',
    'tasteless',
    'tastelessly',
    'tastelessness',
    'taster',
    'tastes',
    'tastiness',
    'tasting',
    'tasty',
    'tat',
    'tatahumara',
    'tatar',
    'tatary',
    'tate',
    'tater',
    'tati',
    'tatou',
    'tatouay',
    'tatter',
    'tatterdemalion',
    'tattered',
    'tatting',
    'tattle',
    'tattler',
    'tattlers',
    'tattletale',
    'tattoo',
    'tattooing',
    'tattoos',
    'tatty',
    'tatu',
    'tatum',
    'tau',
    'taught',
    'taunt',
    'taunted',
    'taunting',
    'tauon',
    'taupe',
    'taurine',
    'tauromachy',
    'taurotragus',
    'taurus',
    'taut',
    'tauten',
    'tautness',
    'tautog',
    'tautoga',
    'tautogolabrus',
    'tautogs',
    'tautologic',
    'tautological',
    'tautology',
    'tavern',
    'taw',
    'tawdriness',
    'tawdry',
    'tawney',
    'tawniness',
    'tawny',
    'tawse',
    'tax',
    'taxa',
    'taxability',
    'taxable',
    'taxaceae',
    'taxales',
    'taxation',
    'taxed',
    'taxer',
    'taxes',
    'taxi',
    'taxicab',
    'taxidea',
    'taxidermist',
    'taxidermy',
    'taxidriver',
    'taxied',
    'taxiing',
    'taximan',
    'taximeter',
    'taxing',
    'taxis',
    'taxistand',
    'taxiway',
    'taxman',
    'taxodiaceae',
    'taxodium',
    'taxoides',
    'taxon',
    'taxonomer',
    'taxonomic',
    'taxonomical',
    'taxonomically',
    'taxonomies',
    'taxonomist',
    'taxonomists',
    'taxonomy',
    'taxophytina',
    'taxopsida',
    'taxpayer',
    'taxpayers',
    'taxpaying',
    'taxus',
    'tay',
    'tayalic',
    'tayassu',
    'tayassuidae',
    'taylor',
    'tayra',
    'taze',
    'tazicef',
    'tazir',
    'tb',
    'tbilisi',
    'tbit',
    'tc',
    'tce',
    'tchad',
    'tchaikovsky',
    'tchotchke',
    'tchotchkeleh',
    'tcp',
    'tdt',
    'te',
    'tea',
    'teaberry',
    'teacake',
    'teacart',
    'teach',
    'teachable',
    'teacher',
    'teachers',
    'teachership',
    'teaches',
    'teaching',
    'teachings',
    'teacup',
    'teacupful',
    'teacups',
    'teahouse',
    'teak',
    'teakettle',
    'teakwood',
    'teal',
    'teals',
    'team',
    'teamed',
    'teammate',
    'teams',
    'teamster',
    'teamsters',
    'teamwork',
    'teapot',
    'tear',
    'tearaway',
    'teardrop',
    'tearful',
    'tearfulness',
    'teargas',
    'teargassed',
    'tearing',
    'tearjerker',
    'tearless',
    'tearoom',
    'tears',
    'teary',
    'teasdale',
    'tease',
    'teased',
    'teasel',
    'teaser',
    'teases',
    'teashop',
    'teasing',
    'teasle',
    'teaspoon',
    'teaspoonful',
    'teat',
    'teatime',
    'teats',
    'teazel',
    'tebaldi',
    'tebet',
    'tebibit',
    'tebibits',
    'tebibyte',
    'tebibytes',
    'tec',
    'tech',
    'techie',
    'technetium',
    'technical',
    'technicality',
    'technically',
    'technician',
    'technicians',
    'technicolor',
    'technique',
    'techniques',
    'techno',
    'technobabble',
    'technocracy',
    'technocrat',
    'technological',
    'technologically',
    'technologies',
    'technologist',
    'technology',
    'technophile',
    'technophilia',
    'technophilic',
    'technophobe',
    'technophobia',
    'technophobic',
    'techy',
    'tecophilaeacea',
    'tectaria',
    'tectona',
    'tectonic',
    'tectonics',
    'tecumseh',
    'tecumtha',
    'ted',
    'teddy',
    'tedious',
    'tediously',
    'tediousness',
    'tedium',
    'tee',
    'teed',
    'teeing',
    'teem',
    'teeming',
    'teemingness',
    'teen',
    'teenage',
    'teenaged',
    'teenager',
    'teenagers',
    'teens',
    'teensy',
    'teentsy',
    'teeny',
    'teeoff',
    'teepee',
    'teeter',
    'teeterboard',
    'teetertotter',
    'teeth',
    'teethe',
    'teething',
    'teetotal',
    'teetotaler',
    'teetotaling',
    'teetotalism',
    'teetotalist',
    'teetotaller',
    'teetotum',
    'teff',
    'tefillin',
    'teflon',
    'teg',
    'tegu',
    'tegucigalpa',
    'tegular',
    'tegument',
    'teheran',
    'tehran',
    'tehuantepec',
    'teiid',
    'teiidae',
    'teju',
    'tejus',
    'tekki',
    'tektite',
    'tel',
    'telamon',
    'telanthera',
    'telco',
    'telecast',
    'telecaster',
    'telecasting',
    'telecom',
    'telecommerce',
    'telecommunicate',
    'telecommunication',
    'telecommunications',
    'telecommuting',
    'teleconference',
    'teleconferencing',
    'telefax',
    'telefilm',
    'telegnosis',
    'telegnostic',
    'telegram',
    'telegrams',
    'telegraph',
    'telegrapher',
    'telegraphese',
    'telegraphic',
    'telegraphist',
    'telegraphy',
    'telekinesis',
    'telemann',
    'telemark',
    'telemarketing',
    'telemeter',
    'telemetered',
    'telemetry',
    'telencephalon',
    'teleological',
    'teleologist',
    'teleology',
    'teleost',
    'teleostan',
    'teleostei',
    'telepathic',
    'telepathise',
    'telepathist',
    'telepathize',
    'telepathy',
    'telephone',
    'telephoned',
    'telephoner',
    'telephones',
    'telephonic',
    'telephonist',
    'telephony',
    'telephoto',
    'telephotograph',
    'telephotography',
    'teleport',
    'teleportation',
    'teleprinter',
    'teleprocessing',
    'teleprompter',
    'telerobotics',
    'telescope',
    'telescoped',
    'telescopes',
    'telescopic',
    'telescopium',
    'telescopy',
    'teleselling',
    'telethermometer',
    'teletypewriter',
    'televangelism',
    'televangelist',
    'televise',
    'television',
    'teleworking',
    'telex',
    'telexed',
    'telfer',
    'telferage',
    'telint',
    'teliospore',
    'teliospores',
    'tell',
    'teller',
    'tellima',
    'telling',
    'tells',
    'telltale',
    'tellurian',
    'telluric',
    'telluride',
    'tellurides',
    'tellurium',
    'tellus',
    'telly',
    'telocentric',
    'telomerase',
    'telomere',
    'telomeres',
    'telopea',
    'telophase',
    'telosporidia',
    'telpher',
    'telpherage',
    'telsontail',
    'telsontails',
    'telugu',
    'temazepam',
    'temblor',
    'temerarious',
    'temerity',
    'temnospondyli',
    'temp',
    'temper',
    'tempera',
    'temperament',
    'temperamental',
    'temperamentally',
    'temperance',
    'temperary',
    'temperate',
    'temperateness',
    'temperature',
    'temperatures',
    'tempered',
    'tempering',
    'tempest',
    'tempestuous',
    'tempestuousness',
    'templar',
    'template',
    'temple',
    'temples',
    'templet',
    'templetonia',
    'tempo',
    'temporal',
    'temporalis',
    'temporality',
    'temporally',
    'temporalty',
    'temporarily',
    'temporariness',
    'temporary',
    'temporise',
    'temporiser',
    'temporize',
    'temporized',
    'temporizer',
    'tempra',
    'tempt',
    'temptable',
    'temptation',
    'temptations',
    'tempted',
    'tempter',
    'tempting',
    'temptingness',
    'temptress',
    'tempts',
    'tempura',
    'temuco',
    'temujin',
    'ten',
    'tenability',
    'tenable',
    'tenableness',
    'tenacious',
    'tenaciously',
    'tenaciousness',
    'tenacity',
    'tenancy',
    'tenant',
    'tenanted',
    'tenantry',
    'tenants',
    'tench',
    'tend',
    'tended',
    'tendencies',
    'tendencious',
    'tendency',
    'tendentious',
    'tendentiousness',
    'tender',
    'tenderfoot',
    'tendergreen',
    'tenderhearted',
    'tenderheartedness',
    'tenderisation',
    'tenderise',
    'tenderised',
    'tenderiser',
    'tenderization',
    'tenderize',
    'tenderized',
    'tenderizer',
    'tenderloin',
    'tenderly',
    'tenderness',
    'tending',
    'tendinitis',
    'tendinous',
    'tendon',
    'tendonitis',
    'tendons',
    'tendosynovitis',
    'tendrac',
    'tendril',
    'tendrils',
    'tends',
    'tenebrific',
    'tenebrionid',
    'tenebrionidae',
    'tenebrious',
    'tenebrous',
    'tenement',
    'tenerife',
    'tenesmus',
    'tenet',
    'tenets',
    'tenfold',
    'tenge',
    'tenia',
    'tenner',
    'tennessean',
    'tennessee',
    'tenniel',
    'tennis',
    'tenno',
    'tennyson',
    'tenon',
    'tenonitis',
    'tenons',
    'tenor',
    'tenoretic',
    'tenorist',
    'tenormin',
    'tenoroon',
    'tenosynovitis',
    'tenpence',
    'tenpin',
    'tenpins',
    'tenpounder',
    'tenrec',
    'tenrecidae',
    'tenrecs',
    'tense',
    'tensed',
    'tenseness',
    'tenses',
    'tensile',
    'tensimeter',
    'tensing',
    'tensiometer',
    'tension',
    'tensional',
    'tensionless',
    'tensions',
    'tensity',
    'tensor',
    'tent',
    'tentacle',
    'tentacled',
    'tentacles',
    'tentacular',
    'tentaculata',
    'tentative',
    'tentatively',
    'tented',
    'tenter',
    'tenterhook',
    'tenth',
    'tenthredinidae',
    'tenting',
    'tentmaker',
    'tentorium',
    'tents',
    'tenuity',
    'tenuous',
    'tenure',
    'tenured',
    'tenzing',
    'tepal',
    'tepee',
    'tephrosia',
    'tepic',
    'tepid',
    'tepidity',
    'tepidness',
    'tequila',
    'tera',
    'terabit',
    'terabits',
    'terabyte',
    'terabytes',
    'teraflop',
    'terahertz',
    'teras',
    'teratogen',
    'teratogenesis',
    'teratogenic',
    'teratology',
    'teratoma',
    'terazosin',
    'terbinafine',
    'terbium',
    'terce',
    'tercel',
    'tercelet',
    'tercentenary',
    'tercentennial',
    'tercet',
    'terebella',
    'terebellidae',
    'terebinth',
    'teredinid',
    'teredinidae',
    'teredo',
    'terefah',
    'terence',
    'terengganu',
    'teres',
    'teresa',
    'tereshkova',
    'terete',
    'tergiversate',
    'tergiversation',
    'tergiversator',
    'teriyaki',
    'term',
    'termagant',
    'termer',
    'termers',
    'termes',
    'terminable',
    'terminal',
    'terminally',
    'terminals',
    'terminate',
    'terminated',
    'terminates',
    'terminating',
    'termination',
    'terminative',
    'terminator',
    'terminological',
    'terminology',
    'terminus',
    'termite',
    'termites',
    'termitidae',
    'terms',
    'tern',
    'ternary',
    'ternate',
    'ternion',
    'terns',
    'terpene',
    'terpsichore',
    'terpsichorean',
    'terra',
    'terrace',
    'terraced',
    'terraces',
    'terrain',
    'terramycin',
    'terrapene',
    'terrapin',
    'terrapins',
    'terrarium',
    'terrasse',
    'terrassed',
    'terrene',
    'terreplein',
    'terrestrial',
    'terrible',
    'terribleness',
    'terribly',
    'terrier',
    'terriers',
    'terrietia',
    'terrific',
    'terrified',
    'terrify',
    'terrifying',
    'terrine',
    'territorial',
    'territorialisation',
    'territorialise',
    'territoriality',
    'territorialization',
    'territorialize',
    'territories',
    'territory',
    'terror',
    'terrorisation',
    'terrorise',
    'terrorism',
    'terrorist',
    'terrorists',
    'terrorization',
    'terrorize',
    'terrorized',
    'terry',
    'terrycloth',
    'terse',
    'terseness',
    'tertian',
    'tertiary',
    'tertigravida',
    'tertry',
    'tertullian',
    'terylene',
    'terzetto',
    'tesla',
    'tessella',
    'tessellate',
    'tessellated',
    'tessellation',
    'tessera',
    'tesseract',
    'tessin',
    'test',
    'testa',
    'testacea',
    'testacean',
    'testaceous',
    'testament',
    'testamentary',
    'testaments',
    'testate',
    'testator',
    'testatrix',
    'testcross',
    'tested',
    'testee',
    'tester',
    'testes',
    'testicle',
    'testicles',
    'testicular',
    'testiere',
    'testified',
    'testifier',
    'testifies',
    'testify',
    'testifying',
    'testimonial',
    'testimony',
    'testiness',
    'testing',
    'testis',
    'testosterone',
    'tests',
    'testudinata',
    'testudines',
    'testudinidae',
    'testudo',
    'testy',
    'tet',
    'tetanic',
    'tetanilla',
    'tetanus',
    'tetany',
    'tetartanopia',
    'tetchiness',
    'tetchy',
    'teth',
    'tether',
    'tetherball',
    'tethered',
    'tethyidae',
    'tethys',
    'teton',
    'tetra',
    'tetrabasic',
    'tetracaine',
    'tetrachlorethylene',
    'tetrachloride',
    'tetrachloroethylene',
    'tetrachloromethane',
    'tetraclinis',
    'tetracycline',
    'tetrad',
    'tetraethyl',
    'tetrafluoroethylene',
    'tetragon',
    'tetragonal',
    'tetragonia',
    'tetragoniaceae',
    'tetragonurus',
    'tetragram',
    'tetragrammaton',
    'tetrahalide',
    'tetrahedron',
    'tetrahydrocannabinol',
    'tetrahymena',
    'tetraiodothyronine',
    'tetralogy',
    'tetramerous',
    'tetrameter',
    'tetramethyldiarsine',
    'tetrametric',
    'tetraneuris',
    'tetranychid',
    'tetranychidae',
    'tetrao',
    'tetraodontidae',
    'tetraonidae',
    'tetrapod',
    'tetrapturus',
    'tetras',
    'tetrasaccharide',
    'tetraskele',
    'tetraskelion',
    'tetrasporangium',
    'tetraspore',
    'tetravalent',
    'tetrazzini',
    'tetri',
    'tetrode',
    'tetrodotoxin',
    'tetrose',
    'tetroxide',
    'tetryl',
    'tetterwort',
    'tettigoniid',
    'tettigoniidae',
    'teucrium',
    'teutoburger',
    'teuton',
    'teutonic',
    'teutonist',
    'teutons',
    'tevere',
    'tevet',
    'tewkesbury',
    'texan',
    'texans',
    'texarkana',
    'texas',
    'text',
    'textbook',
    'textile',
    'textiles',
    'texts',
    'textual',
    'texture',
    'textured',
    'textures',
    'th',
    'thackeray',
    'thaddaeus',
    'thai',
    'thailand',
    'thais',
    'thalamocortical',
    'thalamus',
    'thalarctos',
    'thalassaemia',
    'thalassemia',
    'thalassic',
    'thalassoma',
    'thales',
    'thalia',
    'thaliacea',
    'thaliana',
    'thalictrum',
    'thalidomide',
    'thalidone',
    'thalli',
    'thallium',
    'thalloid',
    'thallophyta',
    'thallophyte',
    'thallophytes',
    'thallophytic',
    'thallus',
    'thalmencephalon',
    'thalweg',
    'thames',
    'thammuz',
    'thamnophilus',
    'thamnophis',
    'than',
    'thanatology',
    'thanatophobia',
    'thanatopsis',
    'thanatos',
    'thane',
    'thaneship',
    'thank',
    'thankful',
    'thankfulness',
    'thankless',
    'thanks',
    'thanksgiving',
    'tharp',
    'that',
    'thatch',
    'thatched',
    'thatcher',
    'thatcherism',
    'thatcherite',
    'thatching',
    'thaumatolatry',
    'thaumaturge',
    'thaumaturgist',
    'thaumaturgy',
    'thaw',
    'thawed',
    'thawing',
    'thb',
    'thc',
    'thd',
    'the',
    'thea',
    'theaceae',
    'theanthropism',
    'theater',
    'theatergoer',
    'theaters',
    'theatre',
    'theatregoer',
    'theatrical',
    'theatricality',
    'theban',
    'thebans',
    'thebe',
    'thebes',
    'theca',
    'thecodont',
    'thecodontia',
    'thecodonts',
    'thee',
    'theelin',
    'theft',
    'thefts',
    'theia',
    'their',
    'theirs',
    'theism',
    'theist',
    'theistic',
    'theistical',
    'theives',
    'thelarche',
    'thelephoraceae',
    'thelypteridaceae',
    'thelypteris',
    'them',
    'thematic',
    'theme',
    'themes',
    'themis',
    'themistocles',
    'themselves',
    'then',
    'thenal',
    'thenar',
    'theobid',
    'theobroma',
    'theocracy',
    'theocratic',
    'theodicy',
    'theodolite',
    'theodor',
    'theodore',
    'theodosius',
    'theogony',
    'theologiae',
    'theologian',
    'theologians',
    'theological',
    'theologise',
    'theologiser',
    'theologist',
    'theologize',
    'theologizer',
    'theology',
    'theophany',
    'theophrastaceae',
    'theophrastus',
    'theophylline',
    'theorem',
    'theorems',
    'theoretic',
    'theoretical',
    'theoretically',
    'theoretician',
    'theories',
    'theorisation',
    'theorise',
    'theoriser',
    'theorist',
    'theorization',
    'theorize',
    'theorized',
    'theorizer',
    'theorizes',
    'theory',
    'theosophical',
    'theosophism',
    'theosophist',
    'theosophy',
    'theoterrorism',
    'therapeutic',
    'therapeutical',
    'therapeutically',
    'therapeutics',
    'theraphosidae',
    'therapies',
    'therapist',
    'therapsid',
    'therapsida',
    'therapsids',
    'therapy',
    'theravada',
    'there',
    'thereafter',
    'thereby',
    'therefore',
    'therein',
    'theremin',
    'thereness',
    'theresa',
    'theridiid',
    'theridiidae',
    'therm',
    'thermal',
    'thermalgesia',
    'thermally',
    'thermel',
    'thermic',
    'thermidor',
    'thermion',
    'thermionic',
    'thermionics',
    'thermistor',
    'thermoacidophile',
    'thermobaric',
    'thermobia',
    'thermocautery',
    'thermochemistry',
    'thermocoagulation',
    'thermocouple',
    'thermodynamic',
    'thermodynamical',
    'thermodynamics',
    'thermoelectric',
    'thermoelectrical',
    'thermoelectricity',
    'thermogram',
    'thermograph',
    'thermography',
    'thermogravimeter',
    'thermogravimetric',
    'thermogravimetry',
    'thermohydrometer',
    'thermohydrometric',
    'thermojunction',
    'thermolabile',
    'thermometer',
    'thermometric',
    'thermometrograph',
    'thermometry',
    'thermonuclear',
    'thermopile',
    'thermoplastic',
    'thermoplastics',
    'thermopsis',
    'thermopylae',
    'thermoreceptor',
    'thermoregulator',
    'thermos',
    'thermoset',
    'thermosetting',
    'thermosphere',
    'thermostat',
    'thermostatic',
    'thermostatics',
    'thermotherapy',
    'thermotropism',
    'theropod',
    'theropoda',
    'theropods',
    'thesaurus',
    'these',
    'theseus',
    'thesis',
    'thespesia',
    'thespian',
    'thespis',
    'thessalia',
    'thessalian',
    'thessalonian',
    'thessalonians',
    'thessalonica',
    'thessaloniki',
    'thessaly',
    'theta',
    'thetis',
    'theumy',
    'theurgy',
    'thevetia',
    'they',
    'thiabendazole',
    'thiamin',
    'thiamine',
    'thiazide',
    'thiazine',
    'thibet',
    'thick',
    'thicken',
    'thickened',
    'thickener',
    'thickening',
    'thickens',
    'thicker',
    'thickest',
    'thicket',
    'thickets',
    'thickhead',
    'thickheaded',
    'thickly',
    'thickness',
    'thicknesses',
    'thickset',
    'thickspread',
    'thief',
    'thielavia',
    'thieve',
    'thievery',
    'thieves',
    'thieving',
    'thievish',
    'thievishness',
    'thigh',
    'thighbone',
    'thighs',
    'thill',
    'thimble',
    'thimbleberry',
    'thimbleful',
    'thimblerig',
    'thimbles',
    'thimbleweed',
    'thimerosal',
    'thin',
    'thing',
    'thingamabob',
    'thingamajig',
    'thingmabob',
    'thingmajig',
    'things',
    'thingumabob',
    'thingumajig',
    'thingummy',
    'think',
    'thinkable',
    'thinker',
    'thinkers',
    'thinking',
    'thinks',
    'thinly',
    'thinned',
    'thinner',
    'thinness',
    'thinning',
    'thins',
    'thiobacillus',
    'thiobacteria',
    'thiobacteriaceae',
    'thiocyanate',
    'thiocyanic',
    'thiodiphenylamine',
    'thioguanine',
    'thiopental',
    'thioridazine',
    'thiosulfil',
    'thiotepa',
    'thiothixene',
    'thiouracil',
    'third',
    'thirdhand',
    'thirst',
    'thirster',
    'thirstiness',
    'thirsty',
    'thirteen',
    'thirteenth',
    'thirties',
    'thirtieth',
    'thirty',
    'thiry',
    'this',
    'thistle',
    'thistledown',
    'thistlelike',
    'thistles',
    'thlaspi',
    'thm',
    'tho',
    'thole',
    'tholepin',
    'thomas',
    'thomism',
    'thomomys',
    'thompson',
    'thomson',
    'thong',
    'thongs',
    'thor',
    'thoracentesis',
    'thoracic',
    'thoracocentesis',
    'thoracoepigastric',
    'thoracotomy',
    'thorax',
    'thorazine',
    'thoreau',
    'thoreauvian',
    'thoriate',
    'thoriated',
    'thorite',
    'thorium',
    'thorn',
    'thornbill',
    'thornbills',
    'thorndike',
    'thorniness',
    'thornless',
    'thorns',
    'thornton',
    'thorny',
    'thorough',
    'thoroughbred',
    'thoroughfare',
    'thoroughgoing',
    'thoroughly',
    'thoroughness',
    'thoroughwort',
    'thorpe',
    'thorshavn',
    'thortveitite',
    'those',
    'thoth',
    'thou',
    'though',
    'thought',
    'thoughtful',
    'thoughtfulness',
    'thoughtless',
    'thoughtlessly',
    'thoughtlessness',
    'thoughts',
    'thousand',
    'thousands',
    'thousandth',
    'thrace',
    'thracian',
    'thraldom',
    'thrall',
    'thralldom',
    'thrash',
    'thrashed',
    'thrasher',
    'thrashers',
    'thrashing',
    'thraupidae',
    'thread',
    'threadbare',
    'threaded',
    'threader',
    'threadfin',
    'threadfins',
    'threadfish',
    'threading',
    'threadless',
    'threadlike',
    'threads',
    'threadworm',
    'thready',
    'threat',
    'threaten',
    'threatened',
    'threatening',
    'threateningly',
    'threatens',
    'threats',
    'three',
    'threefold',
    'threepence',
    'threepenny',
    'threescore',
    'threesome',
    'threnody',
    'threonine',
    'thresh',
    'threshed',
    'thresher',
    'threshes',
    'threshing',
    'threshold',
    'thresholds',
    'threskiornis',
    'threskiornithidae',
    'threw',
    'thrice',
    'thrift',
    'thriftiness',
    'thriftless',
    'thriftlessness',
    'thriftshop',
    'thrifty',
    'thrill',
    'thrilled',
    'thriller',
    'thrillers',
    'thrillful',
    'thrilling',
    'thrills',
    'thrinax',
    'thrip',
    'thripid',
    'thripidae',
    'thrips',
    'thrive',
    'thrives',
    'thriving',
    'throat',
    'throated',
    'throats',
    'throatwort',
    'throaty',
    'throb',
    'throbbing',
    'throe',
    'throes',
    'thrombasthenia',
    'thrombectomy',
    'thrombin',
    'thrombocyte',
    'thrombocytopenia',
    'thrombocytosis',
    'thromboembolism',
    'thrombokinase',
    'thrombolysis',
    'thrombolytic',
    'thrombopenia',
    'thrombophlebitis',
    'thromboplastin',
    'thrombose',
    'thrombosed',
    'thrombosis',
    'thrombus',
    'throne',
    'throng',
    'thronged',
    'throngs',
    'throstle',
    'throttle',
    'throttlehold',
    'throttler',
    'throttling',
    'through',
    'throughout',
    'throughput',
    'throughway',
    'throw',
    'throwaway',
    'throwback',
    'thrower',
    'throwing',
    'thrown',
    'throws',
    'throwster',
    'thrum',
    'thrumming',
    'thrush',
    'thrushes',
    'thrust',
    'thruster',
    'thrusting',
    'thrusts',
    'thruway',
    'thryothorus',
    'thucydides',
    'thud',
    'thudded',
    'thudding',
    'thug',
    'thuggee',
    'thuggery',
    'thugs',
    'thuja',
    'thujopsis',
    'thule',
    'thulium',
    'thumb',
    'thumbed',
    'thumbhole',
    'thumbnail',
    'thumbnut',
    'thumbprint',
    'thumbs',
    'thumbscrew',
    'thumbstall',
    'thumbtack',
    'thumbtacked',
    'thump',
    'thumping',
    'thunbergia',
    'thunder',
    'thunderbird',
    'thunderbolt',
    'thunderclap',
    'thundercloud',
    'thundered',
    'thunderer',
    'thunderhead',
    'thundering',
    'thunderings',
    'thunderous',
    'thunders',
    'thundershower',
    'thunderstorm',
    'thunderstorms',
    'thunderstruck',
    'thundery',
    'thunk',
    'thunnus',
    'thurber',
    'thurible',
    'thurifer',
    'thurify',
    'thuringia',
    'thursday',
    'thus',
    'thwack',
    'thwart',
    'thwarted',
    'thwarter',
    'thwarting',
    'thwarts',
    'thwartwise',
    'thy',
    'thylacine',
    'thylacinus',
    'thylogale',
    'thyme',
    'thymelaeaceae',
    'thymelaeales',
    'thymidine',
    'thymine',
    'thymol',
    'thymosin',
    'thymus',
    'thyreophora',
    'thyreophoran',
    'thyrocalcitonin',
    'thyroglobulin',
    'thyroid',
    'thyroidal',
    'thyroidectomy',
    'thyroiditis',
    'thyromegaly',
    'thyronine',
    'thyroprotein',
    'thyrotoxic',
    'thyrotoxicosis',
    'thyrotrophin',
    'thyrotropin',
    'thyroxin',
    'thyroxine',
    'thyrse',
    'thyrsopteris',
    'thyrsus',
    'thysanocarpus',
    'thysanopter',
    'thysanoptera',
    'thysanopteron',
    'thysanura',
    'thysanuron',
    'thz',
    'ti',
    'tia',
    'tiago',
    'tiamat',
    'tianjin',
    'tiara',
    'tiarella',
    'tib',
    'tiber',
    'tiberius',
    'tibet',
    'tibetan',
    'tibia',
    'tibial',
    'tibialis',
    'tibicen',
    'tibit',
    'tibur',
    'tic',
    'tical',
    'tichodroma',
    'tichodrome',
    'ticino',
    'tick',
    'ticked',
    'ticker',
    'ticket',
    'tickets',
    'ticking',
    'tickle',
    'tickled',
    'tickler',
    'tickling',
    'ticklish',
    'ticks',
    'tickseed',
    'ticktack',
    'ticktacktoe',
    'ticktacktoo',
    'ticktock',
    'tickweed',
    'ticonderoga',
    'tics',
    'tictac',
    'tidal',
    'tidbit',
    'tiddler',
    'tiddly',
    'tiddlywinks',
    'tide',
    'tideland',
    'tidemark',
    'tides',
    'tidewater',
    'tideway',
    'tidiness',
    'tidings',
    'tidy',
    'tidytips',
    'tie',
    'tieback',
    'tiebreaker',
    'tied',
    'tien',
    'tientsin',
    'tiepin',
    'tiepolo',
    'tier',
    'tierce',
    'tiercel',
    'tiered',
    'tierra',
    'tiers',
    'ties',
    'tiff',
    'tiffany',
    'tiffin',
    'tiflis',
    'tiger',
    'tigerish',
    'tigers',
    'tight',
    'tighten',
    'tightened',
    'tightening',
    'tighter',
    'tightfisted',
    'tightfistedness',
    'tightfitting',
    'tightlipped',
    'tightly',
    'tightness',
    'tightrope',
    'tights',
    'tightwad',
    'tiglium',
    'tiglon',
    'tigon',
    'tigress',
    'tigris',
    'tijuana',
    'tike',
    'til',
    'tilapia',
    'tilde',
    'tilden',
    'tile',
    'tiled',
    'tilefish',
    'tiler',
    'tiles',
    'tilia',
    'tiliaceae',
    'tiling',
    'tiliomycetes',
    'till',
    'tillable',
    'tillage',
    'tillandsia',
    'tilled',
    'tiller',
    'tillers',
    'tilletia',
    'tilletiaceae',
    'tillich',
    'tilling',
    'tills',
    'tilt',
    'tilted',
    'tilter',
    'tilth',
    'tilting',
    'tiltyard',
    'tim',
    'timalia',
    'timaliidae',
    'timbale',
    'timber',
    'timbered',
    'timberland',
    'timberline',
    'timberman',
    'timbers',
    'timbre',
    'timbrel',
    'timbuktu',
    'time',
    'timecard',
    'timed',
    'timeing',
    'timekeeper',
    'timekeeping',
    'timeless',
    'timelessness',
    'timeline',
    'timeliness',
    'timely',
    'timepiece',
    'timer',
    'times',
    'timeserver',
    'timeserving',
    'timetable',
    'timework',
    'timeworn',
    'timgad',
    'timid',
    'timidity',
    'timidly',
    'timidness',
    'timimoun',
    'timing',
    'timolol',
    'timor',
    'timorese',
    'timorous',
    'timorousness',
    'timothy',
    'timpani',
    'timpanist',
    'timucu',
    'timur',
    'tin',
    'tinamidae',
    'tinamiformes',
    'tinamou',
    'tinamous',
    'tinbergen',
    'tinca',
    'tinct',
    'tincture',
    'tinctured',
    'tinctures',
    'tindal',
    'tindale',
    'tinder',
    'tinderbox',
    'tine',
    'tinea',
    'tined',
    'tineid',
    'tineidae',
    'tineoid',
    'tineoidea',
    'tineola',
    'tines',
    'tinfoil',
    'ting',
    'tinge',
    'tinged',
    'tingidae',
    'tingle',
    'tingling',
    'tininess',
    'tink',
    'tinker',
    'tinkerer',
    'tinkle',
    'tinkling',
    'tinkly',
    'tinned',
    'tinner',
    'tinning',
    'tinnitus',
    'tinny',
    'tinplate',
    'tinpot',
    'tins',
    'tinsel',
    'tinseled',
    'tinselly',
    'tinsmith',
    'tinsnips',
    'tint',
    'tintack',
    'tinted',
    'tinter',
    'tinting',
    'tintinnabulate',
    'tintinnabulation',
    'tintometer',
    'tintoretto',
    'tints',
    'tinware',
    'tiny',
    'tip',
    'tipi',
    'tipped',
    'tipper',
    'tippet',
    'tipple',
    'tippled',
    'tippler',
    'tippy',
    'tippytoe',
    'tips',
    'tipsiness',
    'tipstaff',
    'tipster',
    'tipsy',
    'tiptoe',
    'tiptop',
    'tipu',
    'tipuana',
    'tipulidae',
    'tirade',
    'tiramisu',
    'tirana',
    'tire',
    'tired',
    'tiredness',
    'tireless',
    'tirelessness',
    'tires',
    'tiresias',
    'tiresome',
    'tiresomely',
    'tiresomeness',
    'tiring',
    'tiro',
    'tirol',
    'tirolean',
    'tisane',
    'tisanes',
    'tishri',
    'tisiphone',
    'tissue',
    'tissues',
    'tit',
    'titan',
    'titaness',
    'titania',
    'titanic',
    'titanium',
    'titanosaur',
    'titanosaurian',
    'titanosauridae',
    'titanosaurus',
    'titans',
    'titbit',
    'titer',
    'titfer',
    'tithe',
    'tithed',
    'tither',
    'tithes',
    'tithonia',
    'titi',
    'titian',
    'titillate',
    'titillated',
    'titillating',
    'titillation',
    'titis',
    'titivate',
    'titivation',
    'titlark',
    'title',
    'titled',
    'titles',
    'titmice',
    'titmouse',
    'tito',
    'titrate',
    'titration',
    'titrations',
    'titrator',
    'titre',
    'titter',
    'titterer',
    'tittering',
    'tittivate',
    'tittivation',
    'tittle',
    'tittup',
    'titty',
    'titular',
    'titulary',
    'titus',
    'tiu',
    'tivoli',
    'tiyin',
    'tizzy',
    'tko',
    'tl',
    'tlc',
    'tlingit',
    'tm',
    'tmv',
    'tn',
    'tnf',
    'tnt',
    'to',
    'toad',
    'toadfish',
    'toadfishes',
    'toadflax',
    'toads',
    'toadshade',
    'toadstool',
    'toady',
    'toadyish',
    'toast',
    'toasted',
    'toaster',
    'toasting',
    'toastmaster',
    'toastrack',
    'toasts',
    'tobacco',
    'tobacconist',
    'tobaccos',
    'tobago',
    'tobagonian',
    'tobey',
    'tobias',
    'tobin',
    'tobit',
    'toboggan',
    'tobogganing',
    'tobogganist',
    'toboggans',
    'tobramycin',
    'toby',
    'tocainide',
    'tocantins',
    'toccata',
    'tocharian',
    'tocktact',
    'tocology',
    'tocopherol',
    'tocqueville',
    'tocsin',
    'tod',
    'toda',
    'today',
    'todd',
    'toddle',
    'toddler',
    'toddlers',
    'toddy',
    'todea',
    'todidae',
    'todies',
    'todus',
    'tody',
    'toe',
    'toea',
    'toecap',
    'toed',
    'toehold',
    'toeless',
    'toenail',
    'toenails',
    'toes',
    'toetoe',
    'toff',
    'toffee',
    'toffy',
    'tofieldia',
    'tofranil',
    'tofu',
    'tog',
    'toga',
    'togaviridae',
    'together',
    'togetherness',
    'togged',
    'toggle',
    'toggles',
    'togo',
    'togolese',
    'togs',
    'toil',
    'toiler',
    'toilet',
    'toiletries',
    'toiletry',
    'toilets',
    'toilette',
    'toiling',
    'toilsome',
    'toilsomeness',
    'toitoi',
    'tojo',
    'tokamak',
    'tokay',
    'toke',
    'token',
    'tokenish',
    'tokens',
    'tokes',
    'tokio',
    'toklas',
    'tokyo',
    'tolazamide',
    'tolazoline',
    'tolbooth',
    'tolbukhin',
    'tolbutamide',
    'told',
    'tole',
    'tolectin',
    'toledo',
    'tolerable',
    'tolerance',
    'tolerant',
    'tolerate',
    'tolerated',
    'tolerates',
    'tolerating',
    'toleration',
    'tolinase',
    'tolkien',
    'toll',
    'tollbar',
    'tollbooth',
    'tollbooths',
    'toller',
    'tollgate',
    'tollgatherer',
    'tollhouse',
    'tollkeeper',
    'tollman',
    'tollon',
    'tolls',
    'tolmiea',
    'tolstoy',
    'toltec',
    'tolu',
    'toluene',
    'tolypeutes',
    'tom',
    'tomahawk',
    'tomalley',
    'tomatillo',
    'tomato',
    'tomatoes',
    'tomb',
    'tombac',
    'tombak',
    'tombaugh',
    'tombigbee',
    'tombola',
    'tomboy',
    'tomboyish',
    'tomboyishness',
    'tombs',
    'tombstone',
    'tomcat',
    'tome',
    'tomentose',
    'tomentous',
    'tomentum',
    'tomfool',
    'tomfoolery',
    'tomistoma',
    'tommyrot',
    'tomograph',
    'tomography',
    'tomorrow',
    'tompion',
    'tomtate',
    'tomtit',
    'ton',
    'tonal',
    'tonality',
    'tone',
    'toned',
    'toneless',
    'toner',
    'tones',
    'tonga',
    'tongan',
    'tongs',
    'tongue',
    'tongued',
    'tonguefish',
    'tonguefishes',
    'tongueflower',
    'tongueless',
    'tonguelike',
    'tongues',
    'tonic',
    'tonicity',
    'tonight',
    'tonka',
    'tonnage',
    'tonne',
    'tonocard',
    'tonometer',
    'tonometry',
    'tons',
    'tonsil',
    'tonsilla',
    'tonsillectomy',
    'tonsillitis',
    'tonsils',
    'tonsorial',
    'tonsure',
    'tonsured',
    'tontine',
    'tonus',
    'too',
    'took',
    'tool',
    'toolbox',
    'tooled',
    'toolhouse',
    'toolmaker',
    'tools',
    'toolshed',
    'toon',
    'toona',
    'tooshie',
    'toot',
    'tooth',
    'toothache',
    'toothbrush',
    'toothed',
    'toothless',
    'toothlike',
    'toothpaste',
    'toothpastes',
    'toothpick',
    'toothpowder',
    'toothsome',
    'toothsomeness',
    'toothwort',
    'toothy',
    'tootle',
    'tootles',
    'tootling',
    'top',
    'topaz',
    'topcoat',
    'topdress',
    'tope',
    'topee',
    'topeka',
    'toper',
    'topgallant',
    'tophus',
    'topi',
    'topiary',
    'topic',
    'topical',
    'topicality',
    'topicalization',
    'topicalize',
    'topicalized',
    'topically',
    'topics',
    'topknot',
    'topknotted',
    'topless',
    'topmast',
    'topminnow',
    'topminnows',
    'topmost',
    'topnotch',
    'topognosia',
    'topognosis',
    'topographic',
    'topographical',
    'topographically',
    'topography',
    'topolatry',
    'topologic',
    'topological',
    'topologically',
    'topologies',
    'topology',
    'toponomy',
    'toponym',
    'toponymy',
    'topos',
    'topped',
    'topper',
    'topping',
    'topple',
    'toppled',
    'tops',
    'topsail',
    'topside',
    'topsoil',
    'topspin',
    'topv',
    'toque',
    'tor',
    'toradol',
    'torah',
    'torch',
    'torchbearer',
    'torched',
    'torches',
    'torchlight',
    'tore',
    'toreador',
    'torero',
    'tories',
    'torino',
    'torment',
    'tormented',
    'tormenter',
    'tormenting',
    'tormentor',
    'torments',
    'torn',
    'tornado',
    'tornillo',
    'torodal',
    'toroid',
    'toroidal',
    'toronto',
    'torpedinidae',
    'torpediniformes',
    'torpedo',
    'torpedoes',
    'torpedos',
    'torpid',
    'torpidity',
    'torpidness',
    'torpor',
    'torque',
    'torquemada',
    'torr',
    'torrent',
    'torrential',
    'torreon',
    'torres',
    'torreya',
    'torricelli',
    'torrid',
    'torridity',
    'torsion',
    'torsk',
    'torso',
    'tort',
    'torte',
    'tortellini',
    'tortfeasor',
    'torticollis',
    'tortilla',
    'tortious',
    'tortoise',
    'tortoises',
    'tortoiseshell',
    'tortricid',
    'tortricidae',
    'tortrix',
    'tortuosities',
    'tortuosity',
    'tortuous',
    'tortuousness',
    'torture',
    'tortured',
    'torturer',
    'torturers',
    'tortures',
    'torturesome',
    'torturing',
    'torturous',
    'torulose',
    'torus',
    'tory',
    'toscana',
    'toscanini',
    'tosh',
    'tosk',
    'toss',
    'tossed',
    'tosser',
    'tosses',
    'tossing',
    'tossup',
    'tostada',
    'tot',
    'total',
    'totaled',
    'totalisator',
    'totalise',
    'totaliser',
    'totalism',
    'totalistic',
    'totalitarian',
    'totalitarianism',
    'totality',
    'totalizator',
    'totalize',
    'totalizer',
    'totally',
    'totals',
    'totara',
    'tote',
    'totem',
    'totemic',
    'totemism',
    'totemist',
    'toter',
    'totipotence',
    'totipotency',
    'totipotent',
    'totter',
    'tottered',
    'totterer',
    'tottering',
    'tottery',
    'toucan',
    'toucanet',
    'toucans',
    'touch',
    'touchable',
    'touchback',
    'touchdown',
    'touched',
    'toucher',
    'touches',
    'touchiness',
    'touching',
    'touchline',
    'touchscreen',
    'touchstone',
    'touchwood',
    'touchy',
    'tough',
    'toughen',
    'toughened',
    'tougher',
    'toughie',
    'toughness',
    'toughs',
    'toulon',
    'toulouse',
    'toupe',
    'toupee',
    'toupeed',
    'tour',
    'touraco',
    'touracos',
    'toured',
    'tourer',
    'tourette',
    'touring',
    'tourism',
    'tourist',
    'touristed',
    'touristry',
    'tourists',
    'touristy',
    'tourmaline',
    'tournament',
    'tournaments',
    'tournedos',
    'tourney',
    'tourniquet',
    'tours',
    'tourtiere',
    'tousle',
    'tousled',
    'tout',
    'touted',
    'touter',
    'tovarich',
    'tovarisch',
    'tow',
    'towage',
    'toward',
    'towards',
    'towboat',
    'towed',
    'towel',
    'toweling',
    'towelling',
    'towels',
    'tower',
    'towering',
    'towers',
    'towhead',
    'towheaded',
    'towhee',
    'towhees',
    'towing',
    'towline',
    'town',
    'townee',
    'towner',
    'townes',
    'townie',
    'towns',
    'townsend',
    'townsendia',
    'townsfolk',
    'township',
    'townships',
    'townsman',
    'townspeople',
    'towny',
    'towpath',
    'towrope',
    'toxaemia',
    'toxemia',
    'toxic',
    'toxicant',
    'toxicity',
    'toxicodendron',
    'toxicognath',
    'toxicognaths',
    'toxicologic',
    'toxicological',
    'toxicologist',
    'toxicology',
    'toxin',
    'toxins',
    'toxoid',
    'toxoplasmosis',
    'toxostoma',
    'toxotes',
    'toxotidae',
    'toy',
    'toying',
    'toynbee',
    'toyohashi',
    'toyon',
    'toyonaki',
    'toyota',
    'toys',
    'toyshop',
    'tpn',
    'trabeate',
    'trabeated',
    'trabecula',
    'trabeculae',
    'trabecular',
    'trabeculate',
    'trablous',
    'trace',
    'traceable',
    'traced',
    'tracer',
    'tracery',
    'traces',
    'trachea',
    'tracheae',
    'tracheal',
    'tracheid',
    'tracheids',
    'tracheitis',
    'trachelospermum',
    'tracheobronchitis',
    'tracheophyta',
    'tracheophyte',
    'tracheophytes',
    'tracheostomy',
    'tracheotomy',
    'trachinotus',
    'trachipteridae',
    'trachipterus',
    'trachodon',
    'trachodont',
    'trachoma',
    'trachurus',
    'tracing',
    'tracings',
    'track',
    'trackable',
    'trackball',
    'tracked',
    'tracker',
    'tracking',
    'tracklayer',
    'trackless',
    'tracks',
    'tract',
    'tractability',
    'tractable',
    'tractableness',
    'tractarian',
    'tractarianism',
    'tractile',
    'traction',
    'tractive',
    'tractor',
    'tracts',
    'tracy',
    'trad',
    'trade',
    'tradecraft',
    'traded',
    'trademark',
    'trademarked',
    'trademarks',
    'tradeoff',
    'trader',
    'traders',
    'trades',
    'tradescant',
    'tradescantia',
    'tradesman',
    'tradespeople',
    'trading',
    'tradition',
    'traditional',
    'traditionalism',
    'traditionalist',
    'traditionalistic',
    'traditionality',
    'traditionally',
    'traditions',
    'traduce',
    'traducement',
    'traducer',
    'trafalgar',
    'traffic',
    'trafficator',
    'trafficked',
    'trafficker',
    'trafficking',
    'tragacanth',
    'tragedian',
    'tragedians',
    'tragedienne',
    'tragedies',
    'tragedy',
    'tragelaphus',
    'tragic',
    'tragical',
    'tragicomedy',
    'tragicomic',
    'tragicomical',
    'tragopan',
    'tragopogon',
    'tragulidae',
    'tragulus',
    'tragus',
    'trail',
    'trailblazer',
    'trailed',
    'trailer',
    'trailers',
    'trailhead',
    'trailing',
    'trails',
    'train',
    'trainband',
    'trainbandsman',
    'trainbearer',
    'trained',
    'trainee',
    'traineeship',
    'traineeships',
    'trainer',
    'training',
    'trainload',
    'trainman',
    'trainmaster',
    'trains',
    'traipse',
    'trait',
    'traitor',
    'traitorous',
    'traitorously',
    'traitorousness',
    'traitress',
    'traits',
    'trajan',
    'trajectory',
    'tralatitious',
    'tram',
    'tramcar',
    'tramline',
    'trammel',
    'tramontana',
    'tramontane',
    'tramp',
    'tramper',
    'tramping',
    'trample',
    'trampled',
    'trampler',
    'trampling',
    'trampoline',
    'trams',
    'tramway',
    'trance',
    'trancelike',
    'trances',
    'tranche',
    'trandate',
    'trandolapril',
    'tranquil',
    'tranquilising',
    'tranquility',
    'tranquilize',
    'tranquilizer',
    'tranquilizers',
    'tranquilizing',
    'tranquillise',
    'tranquilliser',
    'tranquillising',
    'tranquillity',
    'tranquillize',
    'tranquillizer',
    'tranquillizing',
    'trans',
    'transact',
    'transacted',
    'transacting',
    'transactinide',
    'transaction',
    'transactions',
    'transactor',
    'transacts',
    'transalpine',
    'transaminase',
    'transaminate',
    'transamination',
    'transatlantic',
    'transcaucasia',
    'transcend',
    'transcendence',
    'transcendency',
    'transcendent',
    'transcendental',
    'transcendentalism',
    'transcendentalist',
    'transcending',
    'transcends',
    'transcontinental',
    'transcribe',
    'transcribed',
    'transcriber',
    'transcribes',
    'transcript',
    'transcriptase',
    'transcription',
    'transcultural',
    'transcutaneous',
    'transdermal',
    'transdermic',
    'transduce',
    'transducer',
    'transducing',
    'transduction',
    'transect',
    'transept',
    'transeunt',
    'transexual',
    'transfer',
    'transferability',
    'transferable',
    'transferase',
    'transferases',
    'transfered',
    'transferee',
    'transference',
    'transferer',
    'transfering',
    'transferor',
    'transferrable',
    'transferral',
    'transferred',
    'transferrer',
    'transferrin',
    'transferring',
    'transfers',
    'transfiguration',
    'transfigure',
    'transfigured',
    'transfix',
    'transfixed',
    'transform',
    'transformable',
    'transformation',
    'transformations',
    'transformed',
    'transformer',
    'transformers',
    'transforming',
    'transforms',
    'transfuse',
    'transfused',
    'transfusion',
    'transfusions',
    'transgender',
    'transgendered',
    'transgene',
    'transgress',
    'transgressed',
    'transgresses',
    'transgressing',
    'transgression',
    'transgressions',
    'transgressor',
    'transgressors',
    'transience',
    'transiency',
    'transient',
    'transistor',
    'transistorise',
    'transistorised',
    'transistorize',
    'transistorized',
    'transistors',
    'transit',
    'transition',
    'transitional',
    'transitioned',
    'transitions',
    'transitive',
    'transitiveness',
    'transitivise',
    'transitivity',
    'transitivize',
    'transitivizes',
    'transitoriness',
    'transitory',
    'translatable',
    'translate',
    'translated',
    'translates',
    'translating',
    'translation',
    'translational',
    'translations',
    'translator',
    'transliterate',
    'transliterated',
    'transliteration',
    'translocate',
    'translocated',
    'translocation',
    'translucence',
    'translucency',
    'translucent',
    'translunar',
    'translunary',
    'transmigrante',
    'transmigrate',
    'transmigrated',
    'transmigration',
    'transmissible',
    'transmission',
    'transmissions',
    'transmit',
    'transmiting',
    'transmits',
    'transmittable',
    'transmittal',
    'transmittance',
    'transmitted',
    'transmitter',
    'transmitters',
    'transmitting',
    'transmogrification',
    'transmogrify',
    'transmontane',
    'transmundane',
    'transmutability',
    'transmutable',
    'transmutation',
    'transmute',
    'transnational',
    'transoceanic',
    'transom',
    'transonic',
    'transparence',
    'transparencies',
    'transparency',
    'transparent',
    'transparently',
    'transparentness',
    'transpirate',
    'transpiration',
    'transpire',
    'transpired',
    'transpiring',
    'transplacental',
    'transplant',
    'transplantable',
    'transplantation',
    'transplanted',
    'transplanter',
    'transplanting',
    'transplants',
    'transpolar',
    'transponder',
    'transport',
    'transportable',
    'transportation',
    'transported',
    'transporter',
    'transporting',
    'transports',
    'transposability',
    'transposable',
    'transpose',
    'transposed',
    'transposing',
    'transposition',
    'transposon',
    'transsexual',
    'transsexualism',
    'transship',
    'transshipment',
    'transubstantiate',
    'transubstantiation',
    'transudate',
    'transudation',
    'transude',
    'transudes',
    'transuranic',
    'transvaal',
    'transversal',
    'transverse',
    'transversely',
    'transvestic',
    'transvestism',
    'transvestite',
    'transvestitism',
    'transylvania',
    'transylvanian',
    'tranylcypromine',
    'trap',
    'trapa',
    'trapaceae',
    'trapeze',
    'trapezium',
    'trapeziums',
    'trapezius',
    'trapezohedron',
    'trapezoid',
    'trapezoidal',
    'trapezoids',
    'trapped',
    'trapper',
    'trapping',
    'trappings',
    'trappist',
    'traps',
    'trapshooter',
    'trapshooters',
    'trapshooting',
    'trash',
    'trashiness',
    'trashy',
    'trasimeno',
    'traub',
    'traubel',
    'trauma',
    'traumatic',
    'traumatise',
    'traumatize',
    'traumatology',
    'traumatophobia',
    'trautvetteria',
    'travail',
    'trave',
    'travel',
    'travelable',
    'traveled',
    'traveler',
    'travelers',
    'traveling',
    'travelled',
    'traveller',
    'travellers',
    'travelling',
    'travelog',
    'travelogue',
    'travels',
    'traversable',
    'traversal',
    'traverse',
    'traversed',
    'traverser',
    'traversers',
    'traversing',
    'travesty',
    'trawl',
    'trawler',
    'trawlers',
    'tray',
    'trazodone',
    'treacherous',
    'treachery',
    'treacle',
    'treacly',
    'tread',
    'treading',
    'treadle',
    'treadles',
    'treadmill',
    'treads',
    'treadwheel',
    'treason',
    'treasonable',
    'treasonist',
    'treasonous',
    'treasure',
    'treasured',
    'treasurer',
    'treasurership',
    'treasures',
    'treasury',
    'treat',
    'treated',
    'treater',
    'treaties',
    'treating',
    'treatise',
    'treatment',
    'treatments',
    'treats',
    'treaty',
    'treble',
    'trebuchet',
    'trebucket',
    'tree',
    'treed',
    'treehopper',
    'treehoppers',
    'treeless',
    'treelet',
    'treelets',
    'treelike',
    'treenail',
    'trees',
    'treetop',
    'tref',
    'trefoil',
    'trefoils',
    'treillage',
    'trek',
    'trekked',
    'trekker',
    'trekking',
    'trellis',
    'trema',
    'trematoda',
    'trematode',
    'tremble',
    'trembled',
    'trembler',
    'trembles',
    'trembling',
    'tremella',
    'tremellaceae',
    'tremellales',
    'tremendous',
    'tremens',
    'tremolite',
    'tremolo',
    'tremor',
    'tremors',
    'tremulous',
    'trenail',
    'trench',
    'trenchancy',
    'trenchant',
    'trenched',
    'trencher',
    'trencherman',
    'trenches',
    'trend',
    'trends',
    'trendsetting',
    'trendy',
    'trent',
    'trental',
    'trento',
    'trenton',
    'trepan',
    'trepang',
    'trephination',
    'trephine',
    'trephritidae',
    'trepid',
    'trepidation',
    'treponema',
    'treponemataceae',
    'trespass',
    'trespassed',
    'trespasser',
    'trespassers',
    'trespassing',
    'tress',
    'trestle',
    'trestles',
    'trestlework',
    'trevelyan',
    'trevino',
    'trevithick',
    'trews',
    'trey',
    'trf',
    'trh',
    'triacetate',
    'triad',
    'triaenodon',
    'triage',
    'triakidae',
    'trial',
    'trialeurodes',
    'trials',
    'triamcinolone',
    'triangle',
    'triangles',
    'triangular',
    'triangularity',
    'triangulate',
    'triangulating',
    'triangulation',
    'triangulum',
    'triassic',
    'triatoma',
    'triavil',
    'triazine',
    'triazolam',
    'tribade',
    'tribadism',
    'tribadistic',
    'tribal',
    'tribalisation',
    'tribalism',
    'tribalization',
    'tribe',
    'tribes',
    'tribesman',
    'tribesmen',
    'tribolium',
    'tribologist',
    'tribology',
    'tribonema',
    'tribonemaceae',
    'tribromoethanol',
    'tribromomethane',
    'tribulate',
    'tribulation',
    'tribulus',
    'tribunal',
    'tribunals',
    'tribune',
    'tribuneship',
    'tributaries',
    'tributary',
    'tribute',
    'tributyrin',
    'trice',
    'tricentenary',
    'tricentennial',
    'triceps',
    'triceratops',
    'trichechidae',
    'trichechus',
    'trichina',
    'trichiniasis',
    'trichinosis',
    'trichion',
    'trichiuridae',
    'trichloride',
    'trichlormethiazide',
    'trichloroethane',
    'trichloroethylene',
    'trichloromethane',
    'trichobezoar',
    'trichoceros',
    'trichodesmium',
    'trichodontidae',
    'trichoglossus',
    'tricholoma',
    'tricholomataceae',
    'trichomanes',
    'trichomonad',
    'trichomoniasis',
    'trichophaga',
    'trichophyton',
    'trichoptera',
    'trichopteran',
    'trichopteron',
    'trichostema',
    'trichostigma',
    'trichosurus',
    'trichotillomania',
    'trichotomy',
    'trichroism',
    'trichromacy',
    'trichromatic',
    'trichrome',
    'trichuriasis',
    'trichys',
    'trick',
    'tricked',
    'tricker',
    'trickery',
    'trickiness',
    'trickle',
    'trickled',
    'tricks',
    'trickster',
    'tricksy',
    'tricky',
    'triclinic',
    'triclinium',
    'tricolor',
    'tricolour',
    'tricorn',
    'tricorne',
    'tricot',
    'tricuspid',
    'tricuspidate',
    'tricycle',
    'tricyclic',
    'tridacna',
    'tridacnidae',
    'trident',
    'tridymite',
    'tried',
    'triennial',
    'trier',
    'tries',
    'trifid',
    'trifle',
    'trifler',
    'trifling',
    'trifluoride',
    'trifluoromethane',
    'trifoliata',
    'trifoliate',
    'trifoliated',
    'trifoliolate',
    'trifolium',
    'trifurcate',
    'trifurcates',
    'trifurcation',
    'trig',
    'triga',
    'trigeminal',
    'trigeminus',
    'trigger',
    'triggered',
    'triggerfish',
    'triggerfishes',
    'triggering',
    'triggerman',
    'triggers',
    'triglidae',
    'triglinae',
    'triglochin',
    'triglyceride',
    'triglycerides',
    'trigon',
    'trigonal',
    'trigonella',
    'trigonometric',
    'trigonometrician',
    'trigonometry',
    'trigram',
    'trihydroxy',
    'triiodomethane',
    'triiodothyronine',
    'trike',
    'trilateral',
    'trilby',
    'trilingual',
    'trilisa',
    'trill',
    'trilled',
    'trilliaceae',
    'trilling',
    'trillion',
    'trillionth',
    'trillium',
    'trilobate',
    'trilobated',
    'trilobed',
    'trilobite',
    'trilogy',
    'trim',
    'trimaran',
    'trimer',
    'trimester',
    'trimipramine',
    'trimmed',
    'trimmer',
    'trimmers',
    'trimming',
    'trimmings',
    'trimness',
    'trimorphodon',
    'trimotored',
    'trimox',
    'trims',
    'trimurti',
    'trine',
    'trinectes',
    'tringa',
    'trinidad',
    'trinidadian',
    'trinitarian',
    'trinitarianism',
    'trinitroglycerin',
    'trinitrotoluene',
    'trinity',
    'trinket',
    'trinketry',
    'trinkets',
    'trinuclear',
    'trinucleate',
    'trinucleated',
    'trio',
    'triode',
    'triolein',
    'trionychidae',
    'trionyx',
    'triopidae',
    'triops',
    'triose',
    'triostium',
    'trioxide',
    'trip',
    'tripalmitin',
    'tripartite',
    'tripe',
    'triphammer',
    'triphosphopyridine',
    'triphosphoric',
    'tripinnate',
    'tripinnated',
    'tripinnatifid',
    'triple',
    'tripled',
    'triplet',
    'tripletail',
    'tripletails',
    'triplets',
    'tripleurospermum',
    'triplex',
    'triplicate',
    'triplicity',
    'tripling',
    'triplochiton',
    'triploid',
    'tripod',
    'tripoli',
    'tripos',
    'tripped',
    'tripper',
    'tripping',
    'trips',
    'triptych',
    'triquetral',
    'trireme',
    'trisaccharide',
    'trisect',
    'triskaidekaphobia',
    'triskaidekaphobic',
    'triskele',
    'triskelion',
    'trismus',
    'trisomy',
    'tristan',
    'tristearin',
    'tristram',
    'trisyllable',
    'tritanopia',
    'tritanopic',
    'trite',
    'triteness',
    'tritheism',
    'tritheist',
    'triticum',
    'tritium',
    'tritoma',
    'triton',
    'tritons',
    'triturus',
    'triumph',
    'triumphal',
    'triumphant',
    'triumphs',
    'triumvir',
    'triumvirate',
    'triune',
    'trivalent',
    'trivet',
    'trivia',
    'trivial',
    'trivialise',
    'triviality',
    'trivialize',
    'trivium',
    'trm',
    'trna',
    'troat',
    'trochaic',
    'trochanter',
    'troche',
    'trochee',
    'trochilidae',
    'trochlear',
    'trochlearis',
    'trodden',
    'trogium',
    'troglodyte',
    'troglodytes',
    'troglodytidae',
    'trogon',
    'trogonidae',
    'trogoniformes',
    'trogons',
    'troika',
    'trojan',
    'trojans',
    'troll',
    'trolled',
    'troller',
    'trolley',
    'trolleybus',
    'trolling',
    'trollius',
    'trollop',
    'trollope',
    'trombicula',
    'trombiculiasis',
    'trombiculid',
    'trombiculidae',
    'trombidiid',
    'trombidiidae',
    'trombone',
    'trombonist',
    'trompe',
    'trompillo',
    'trondheim',
    'troop',
    'trooped',
    'trooper',
    'troops',
    'troopship',
    'tropaeolaceae',
    'tropaeolum',
    'trope',
    'trophic',
    'trophies',
    'trophobiosis',
    'trophoblast',
    'trophoblastic',
    'trophotropic',
    'trophotropism',
    'trophozoite',
    'trophy',
    'tropic',
    'tropical',
    'tropicbird',
    'tropicbirds',
    'tropics',
    'tropidoclonion',
    'tropism',
    'troponomy',
    'troponym',
    'troponymy',
    'tropopause',
    'troposphere',
    'trot',
    'troth',
    'trotline',
    'trots',
    'trotsky',
    'trotskyism',
    'trotskyist',
    'trotskyite',
    'trotted',
    'trotter',
    'trotting',
    'troubadour',
    'trouble',
    'troubled',
    'troublemaker',
    'troublemakers',
    'troubler',
    'troubles',
    'troubleshoot',
    'troubleshooter',
    'troublesome',
    'troublesomeness',
    'troubling',
    'troublous',
    'trough',
    'trounce',
    'trouncing',
    'troupe',
    'trouper',
    'trouser',
    'trousered',
    'trousering',
    'trousers',
    'trousseau',
    'trout',
    'trouts',
    'trove',
    'trowel',
    'troy',
    'truancy',
    'truant',
    'truce',
    'truck',
    'truckage',
    'trucker',
    'trucking',
    'truckle',
    'truckler',
    'truckling',
    'trucks',
    'truculence',
    'truculency',
    'truculent',
    'trudge',
    'trudged',
    'trudger',
    'true',
    'truehearted',
    'truelove',
    'trueness',
    'truffaut',
    'truffle',
    'truffles',
    'truism',
    'truly',
    'truman',
    'trumbo',
    'trumbull',
    'trump',
    'trumpery',
    'trumpet',
    'trumpeter',
    'trumpeters',
    'trumpetfish',
    'trumpetfishes',
    'trumpeting',
    'trumpets',
    'trumpetwood',
    'trumping',
    'trumps',
    'truncate',
    'truncated',
    'truncation',
    'truncheon',
    'truncocolumella',
    'trundle',
    'trundled',
    'trunk',
    'trunkfish',
    'trunks',
    'trunnel',
    'truss',
    'trussed',
    'trusses',
    'trust',
    'trustbuster',
    'trusted',
    'trustee',
    'trustees',
    'trusteeship',
    'truster',
    'trustful',
    'trustfulness',
    'trustiness',
    'trusting',
    'trustingness',
    'trustor',
    'trusts',
    'trustworthiness',
    'trustworthy',
    'trusty',
    'truth',
    'truthful',
    'truthfulness',
    'truths',
    'try',
    'trying',
    'tryout',
    'trypetidae',
    'trypsin',
    'trypsinogen',
    'tryptophan',
    'tryptophane',
    'tryst',
    'tsa',
    'tsar',
    'tsarina',
    'tsarist',
    'tsaristic',
    'tsaritsa',
    'tsaritsyn',
    'tsatske',
    'tsetse',
    'tsh',
    'tshatshke',
    'tshiluba',
    'tsimshian',
    'tsine',
    'tsk',
    'tsoris',
    'tsouic',
    'tss',
    'tsuga',
    'tsunami',
    'tsung',
    'tsuris',
    'tsushima',
    'tswana',
    'tt',
    'tuareg',
    'tuatara',
    'tuataras',
    'tuatha',
    'tub',
    'tuba',
    'tubal',
    'tubbiness',
    'tubby',
    'tube',
    'tubed',
    'tubeless',
    'tubelike',
    'tuber',
    'tuberaceae',
    'tuberales',
    'tubercle',
    'tubercles',
    'tubercular',
    'tubercularia',
    'tuberculariaceae',
    'tuberculate',
    'tuberculin',
    'tuberculoid',
    'tuberculosis',
    'tuberculous',
    'tuberose',
    'tuberosity',
    'tuberous',
    'tubers',
    'tuberworm',
    'tubes',
    'tubful',
    'tubing',
    'tubman',
    'tubocurarine',
    'tubs',
    'tubular',
    'tubule',
    'tubules',
    'tubulidentata',
    'tucana',
    'tuchman',
    'tuck',
    'tuckahoe',
    'tucked',
    'tucker',
    'tucket',
    'tucks',
    'tucson',
    'tudor',
    'tudung',
    'tues',
    'tuesday',
    'tufa',
    'tuff',
    'tuffet',
    'tuft',
    'tufted',
    'tufts',
    'tug',
    'tugboat',
    'tugela',
    'tugged',
    'tugger',
    'tughrik',
    'tugrik',
    'tugs',
    'tuileries',
    'tuille',
    'tuition',
    'tularaemia',
    'tularemia',
    'tule',
    'tulestoma',
    'tulip',
    'tulipa',
    'tulips',
    'tulipwood',
    'tulle',
    'tully',
    'tulostoma',
    'tulostomaceae',
    'tulostomataceae',
    'tulostomatales',
    'tulsa',
    'tulu',
    'tum',
    'tumble',
    'tumblebug',
    'tumbled',
    'tumbler',
    'tumblers',
    'tumbles',
    'tumbleweed',
    'tumbling',
    'tumbrel',
    'tumbril',
    'tumefaction',
    'tumefy',
    'tumesce',
    'tumescence',
    'tumescent',
    'tumid',
    'tumidity',
    'tumidness',
    'tummy',
    'tumor',
    'tumors',
    'tumour',
    'tumped',
    'tums',
    'tumult',
    'tumultuous',
    'tumultuousness',
    'tumulus',
    'tun',
    'tuna',
    'tunaburger',
    'tunas',
    'tundra',
    'tune',
    'tuned',
    'tuneful',
    'tunefulness',
    'tuneless',
    'tuner',
    'tunes',
    'tung',
    'tunga',
    'tungstate',
    'tungsten',
    'tungstic',
    'tungus',
    'tungusic',
    'tunguska',
    'tunguz',
    'tunic',
    'tunica',
    'tunicata',
    'tunicate',
    'tunicates',
    'tuning',
    'tunis',
    'tunisia',
    'tunisian',
    'tunker',
    'tunnage',
    'tunnel',
    'tunnels',
    'tunney',
    'tunny',
    'tup',
    'tupaia',
    'tupaiidae',
    'tupek',
    'tupelo',
    'tupi',
    'tupik',
    'tupinambis',
    'tuppence',
    'tuppeny',
    'tupungatito',
    'tupungato',
    'turaco',
    'turacou',
    'turakoo',
    'turban',
    'turbaned',
    'turbatrix',
    'turbellaria',
    'turbid',
    'turbidity',
    'turbidness',
    'turbinal',
    'turbinate',
    'turbine',
    'turbines',
    'turbofan',
    'turbogenerator',
    'turbojet',
    'turboprop',
    'turbot',
    'turbulence',
    'turbulency',
    'turbulent',
    'turcoman',
    'turd',
    'turdidae',
    'turdinae',
    'turdus',
    'tureen',
    'turf',
    'turfan',
    'turgenev',
    'turgid',
    'turgidity',
    'turgidness',
    'turgor',
    'turgot',
    'turin',
    'turing',
    'turk',
    'turkestan',
    'turkey',
    'turkeys',
    'turki',
    'turkic',
    'turkish',
    'turkistan',
    'turkmen',
    'turkmenia',
    'turkmenistan',
    'turkoman',
    'turkomen',
    'turks',
    'turmeric',
    'turmoil',
    'turn',
    'turnabout',
    'turnaround',
    'turnbuckle',
    'turncoat',
    'turncock',
    'turndown',
    'turned',
    'turner',
    'turners',
    'turnery',
    'turnicidae',
    'turning',
    'turnings',
    'turnip',
    'turnips',
    'turnix',
    'turnkey',
    'turnoff',
    'turnout',
    'turnover',
    'turnpike',
    'turnround',
    'turns',
    'turnspit',
    'turnstile',
    'turnstone',
    'turnstones',
    'turntable',
    'turnup',
    'turnverein',
    'turp',
    'turpentine',
    'turpin',
    'turpitude',
    'turpitudes',
    'turps',
    'turquoise',
    'turreae',
    'turret',
    'turritis',
    'tursiops',
    'turtle',
    'turtledove',
    'turtledoves',
    'turtlehead',
    'turtleneck',
    'turtler',
    'turtles',
    'tuscaloosa',
    'tuscan',
    'tuscany',
    'tuscarora',
    'tush',
    'tushery',
    'tusk',
    'tusked',
    'tuskegee',
    'tusker',
    'tusks',
    'tussah',
    'tussaud',
    'tusseh',
    'tusser',
    'tussilago',
    'tussle',
    'tussock',
    'tussore',
    'tussur',
    'tut',
    'tutankhamen',
    'tutee',
    'tutelage',
    'tutelar',
    'tutelary',
    'tutelo',
    'tutor',
    'tutored',
    'tutorial',
    'tutorials',
    'tutors',
    'tutorship',
    'tutsan',
    'tutsi',
    'tutsis',
    'tutu',
    'tutus',
    'tuvalu',
    'tux',
    'tuxedo',
    'tuxedoed',
    'tv',
    'twa',
    'twaddle',
    'twaddler',
    'twain',
    'twang',
    'twanged',
    'twanging',
    'twat',
    'twayblade',
    'tweak',
    'twee',
    'tweed',
    'tweediness',
    'tweedle',
    'tweeds',
    'tweedy',
    'tweet',
    'tweeter',
    'tweeters',
    'tweeting',
    'tweeze',
    'tweezer',
    'tweezers',
    'twelfth',
    'twelfthtide',
    'twelve',
    'twelvemonth',
    'twenties',
    'twentieth',
    'twenty',
    'twerp',
    'twice',
    'twiddle',
    'twiddled',
    'twiddler',
    'twig',
    'twigged',
    'twiggy',
    'twiglike',
    'twigs',
    'twilight',
    'twilit',
    'twill',
    'twilled',
    'twin',
    'twinberry',
    'twine',
    'twined',
    'twiner',
    'twinflower',
    'twinge',
    'twining',
    'twinjet',
    'twinkie',
    'twinkle',
    'twinkler',
    'twinkling',
    'twinkly',
    'twinned',
    'twinning',
    'twins',
    'twirl',
    'twirled',
    'twirler',
    'twirling',
    'twirls',
    'twirp',
    'twist',
    'twisted',
    'twister',
    'twisting',
    'twists',
    'twistwood',
    'twisty',
    'twit',
    'twitch',
    'twitching',
    'twitter',
    'twitterer',
    'twitters',
    'two',
    'twofer',
    'twofold',
    'twopence',
    'twopenny',
    'twoscore',
    'twosome',
    'tx',
    'tyche',
    'tycoon',
    'tying',
    'tyiyn',
    'tyke',
    'tylenchidae',
    'tylenchus',
    'tylenol',
    'tyler',
    'tympan',
    'tympani',
    'tympanic',
    'tympanist',
    'tympanites',
    'tympanitic',
    'tympanitis',
    'tympanoplasty',
    'tympanuchus',
    'tympanum',
    'tyndale',
    'tyndall',
    'tyne',
    'type',
    'typecast',
    'typed',
    'typeface',
    'typefaces',
    'types',
    'typescript',
    'typeset',
    'typesetter',
    'typesetting',
    'typewrite',
    'typewriter',
    'typewriters',
    'typewriting',
    'typewritten',
    'typha',
    'typhaceae',
    'typhi',
    'typhimurium',
    'typhlopidae',
    'typhoeus',
    'typhoid',
    'typhon',
    'typhoon',
    'typhoons',
    'typhosa',
    'typhus',
    'typic',
    'typical',
    'typicality',
    'typically',
    'typification',
    'typified',
    'typifies',
    'typify',
    'typifying',
    'typing',
    'typist',
    'typists',
    'typo',
    'typographer',
    'typographic',
    'typographical',
    'typographically',
    'typography',
    'typology',
    'tyr',
    'tyramine',
    'tyranni',
    'tyrannic',
    'tyrannical',
    'tyrannicide',
    'tyrannid',
    'tyrannidae',
    'tyrannise',
    'tyrannize',
    'tyrannosaur',
    'tyrannosaurus',
    'tyrannous',
    'tyrannus',
    'tyranny',
    'tyrant',
    'tyre',
    'tyrial',
    'tyro',
    'tyrocidin',
    'tyrocidine',
    'tyrol',
    'tyrolean',
    'tyrolese',
    'tyrosine',
    'tyrosinemia',
    'tyrothricin',
    'tyrr',
    'tyrrhenian',
    'tyson',
    'tyto',
    'tytonidae',
    'tzar',
    'tzara',
    'tzarina',
    'tzarist',
    'tzetze']



from .utils import *
from .parser import *
from .tokenizer import *
from .analyze import *

from .utils.dto import Sentences
from .lingpatlab import LingPatLab
from .segmenter import Segmenter


from typing import List
from lingpatlab.baseblock import Enforcer


def tokenize_input_text(input_text: str) -> List[str]:
    """
    Tokenizes the input text into sentences.

    Args:
        input_text (str): The input text to be tokenized.

    Returns:
        List[str]: A list of sentences.

    Raises:
        TypeError: If the input_text is not a string.
        TypeError: If the sentences are not a list of strings.
    """
    Enforcer.is_str(input_text)

    sentences: List[str] = Tokenizer().input_text(input_text)

    Enforcer.is_list_of_str(sentences)

    return sentences


def segment_input_text(input_text: str) -> List[str]:
    """
    Segments the input text into sentences.

    Args:
        input_text (str): The input text to be segmented.

    Returns:
        List[str]: A list of segmented sentences.

    Raises:
        TypeError: If the input_text is not a string.

    """
    Enforcer.is_str(input_text)

    sentences: List[str] = Segmenter().input_text(input_text)

    Enforcer.is_list_of_str(sentences)

    return sentences



# !/usr/bin/env python
# -*- coding: UTF-8 -*-
""" Facade to find Wordnet Data on Disk """


from string import ascii_lowercase

from lingpatlab.baseblock import BaseObject
from lingpatlab.utils.os import (
    wordnet_terms_a, wordnet_terms_b,
    wordnet_terms_c, wordnet_terms_d,
    wordnet_terms_e, wordnet_terms_f,
    wordnet_terms_g, wordnet_terms_h,
    wordnet_terms_i, wordnet_terms_j,
    wordnet_terms_k, wordnet_terms_l,
    wordnet_terms_m, wordnet_terms_n,
    wordnet_terms_o, wordnet_terms_p,
    wordnet_terms_q, wordnet_terms_r,
    wordnet_terms_s, wordnet_terms_t,
    wordnet_terms_u, wordnet_terms_v,
    wordnet_terms_w, wordnet_terms_x,
    wordnet_terms_y, wordnet_terms_z
)


class FindWordnet(BaseObject):
    """ Facade to find Wordnet Data on Disk """

    def __init__(self):
        """
        Created:
            5-Oct-2021
            craigtrim@gmail.com
            *   https://github.com/grafflr/graffl-core/issues/2
        Updated:
            31-Aug-2022
            craigtrim@gmail.com
            *   migrate to solo repo
        Updated:
            27-Feb-2024
            craigtrim@gmail.com
            *   migrate to spacy-core
                https://github.com/craigtrim/datapipe-apis/issues/43
        """
        BaseObject.__init__(self, __name__)

    @staticmethod
    def _exists(input_text: str) -> bool:

        if not input_text or input_text is None or not len(input_text):
            return False

        first_char = input_text[0]
        if first_char not in ascii_lowercase:
            return False

        if first_char == 'a':
            return input_text in wordnet_terms_a
        if first_char == 'b':
            return input_text in wordnet_terms_b
        if first_char == 'c':
            return input_text in wordnet_terms_c
        if first_char == 'd':
            return input_text in wordnet_terms_d
        if first_char == 'e':
            return input_text in wordnet_terms_e
        if first_char == 'f':
            return input_text in wordnet_terms_f
        if first_char == 'g':
            return input_text in wordnet_terms_g
        if first_char == 'h':
            return input_text in wordnet_terms_h
        if first_char == 'i':
            return input_text in wordnet_terms_i
        if first_char == 'j':
            return input_text in wordnet_terms_j
        if first_char == 'k':
            return input_text in wordnet_terms_k
        if first_char == 'l':
            return input_text in wordnet_terms_l
        if first_char == 'm':
            return input_text in wordnet_terms_m
        if first_char == 'n':
            return input_text in wordnet_terms_n
        if first_char == 'o':
            return input_text in wordnet_terms_o
        if first_char == 'p':
            return input_text in wordnet_terms_p
        if first_char == 'q':
            return input_text in wordnet_terms_q
        if first_char == 'r':
            return input_text in wordnet_terms_r
        if first_char == 's':
            return input_text in wordnet_terms_s
        if first_char == 't':
            return input_text in wordnet_terms_t
        if first_char == 'u':
            return input_text in wordnet_terms_u
        if first_char == 'v':
            return input_text in wordnet_terms_v
        if first_char == 'w':
            return input_text in wordnet_terms_w
        if first_char == 'x':
            return input_text in wordnet_terms_x
        if first_char == 'y':
            return input_text in wordnet_terms_y
        if first_char == 'z':
            return input_text in wordnet_terms_z

        raise ValueError(input_text)

    def exists(self,
               input_text: str) -> bool:

        input_text = input_text.lower().strip()

        if self._exists(input_text):
            return True

        if input_text.endswith('s') and len(input_text) > 3:
            if self._exists(input_text[:-1]):
                return True

        return False



#!/usr/bin/env python
# -*- coding: UTF-8 -*-
""" Add Wordnet Flag to Token """


from lingpatlab.baseblock import BaseObject
from lingpatlab.utils import is_wordnet_term


class TokenParserWordnet(BaseObject):
    """ Add Wordnet Flag to Token """

    def __init__(self):
        """ Change Log

        Created:
            13-Oct-2021
            craigtrim@gmail.com
            *   refactored out of 'parse-input-tokens' in pursuit of
                https://github.com/grafflr/graffl-core/issues/41
        Updated:
            31-Aug-2022
            craigtrim@gmail.com
            *   refactor to use 'is-wordnet-term' function
        Updated:
            16-Sept-2022
            craigtrim@gmail.com
            *   rename component
                https://github.com/craigtrim/spacy-token-parser/issues/3
        """
        BaseObject.__init__(self, __name__)

    def process(self,
                tokens: list) -> list:
        """Add Wordnet Flag to tokens that are found in Wordnet
            these tokens are considered 'lexical'; that is,
            they are commonly known words in the english language
            as opposed to industry jargon

        Args:
            tokens (list): list of tokens

        Returns:
            list: list of tokens
        """
        results = []

        for token in tokens:

            def is_wordnet() -> bool:
                if token['is_punct']:
                    return False

                return is_wordnet_term(token['text'])

            token['is_wordnet'] = is_wordnet()
            results.append(token)

        return results



from typing import List

# from .text_summary_prompts import (
#     SYSTEM_PROMPT_SUMMARY,
#     SYSTEM_PROMPT_TEMPLATE_1,
#     SYSTEM_PROMPT_TEMPLATE_2,
#     SAMPLE_ORIGINAL_TEXT,
#     SAMPLE_PHRASES,
#     SAMPLE_OUTPUT,
#     generate_prompt,
#     generate_sample_prompt,
# )

from .text_summary_prompts_2 import (
    SYSTEM_PROMPT_SUMMARY,
    SYSTEM_PROMPT_TEMPLATE,
    SAMPLE_ORIGINAL_TEXT,
    SAMPLE_OUTPUT,
    generate_sample_prompt,
    generate_prompt,
)


def filter_title_phrases(phrases: List[str]) -> List[str]:
    """
    Cleanses a list of phrases by removing possessive suffixes and filtering out phrases that are not capitalized.

    Args:
        phrases (List[str]): A list of phrases to be cleansed.

    Returns:
        List[str]: A list of cleansed phrases.

    """
    def cleanse(input_text: str) -> str:
        if input_text[-2:] == "'s":
            return input_text[:-2]
        return input_text

    phrases = [
        cleanse(phrase) for phrase in phrases
    ]

    def all_upper(phrase: str) -> bool:
        return sum([
            (token[0].isupper() or token.isnumeric()) and len(token) > 1
            for token in phrase.split()
        ]) == len(phrase.split())

    def acceptable_title_case(phrase: str) -> bool:
        tokens = phrase.split()
        if len(tokens) < 3:
            return False

        for token in tokens:
            if token == 'of':
                continue
            if not token[0].isupper():
                return False

        return True

    phrases = [
        phrase for phrase in phrases
        if all_upper(phrase) or acceptable_title_case(phrase)
    ]

    return phrases



#!/usr/bin/env python
# -*- coding: UTF-8 -*-
""" Extract People (with Anaphora Linking) """


from lingpatlab.baseblock import BaseObject, Enforcer
from typing import List, Dict, Optional
from lingpatlab.utils.dto import Sentences
from lingpatlab.analyze.svc import ExtractPersonEntities


class ExtractPeople(BaseObject):
    """ Extract People (with Anaphora Linking) """

    def __init__(self,
                 ):
        """ Change Log

        Created:
            19-Mar-2024
            craigtrim@gmail.com
            *   in pursuit of 
                https://github.com/craigtrim/datapipe-apis/issues/61
        """
        BaseObject.__init__(self, __name__)
        self._extract_people = ExtractPersonEntities().process

    def process(self,
                sentences: Sentences) -> Optional[Dict[str, List[str]]]:

        result = self._extract_people(sentences)

        if self.isEnabledForDebug and result:
            Enforcer.is_dict(result)
            for k in result:
                Enforcer.is_str(k)
                Enforcer.is_list_of_str(result[k])

        return result




#!/usr/bin/env python
# -*- coding: UTF-8 -*-

# pylint:disable=bad-whitespace
# pylint:disable=line-too-long
# pylint:disable=too-many-lines
# pylint:disable=invalid-name

# #########################################################
#
#       ************** !! WARNING !! ***************
#       ******* THIS FILE WAS AUTO-GENERATED *******
#       ********* DO NOT MODIFY THIS FILE **********
#
# #########################################################

wordnet_terms_y_provenance = {
    'action': ['router.py',
               'plac_core.py',
               'csv2py_orchestrator.py',
               'wordnet2py.py',
               'csv_list_writer.py',
               'common_utils.py'],
    'source': 'resources/data/csv/wordnet.csv',
    'time': '2022-05-17 17:00:36.243458'}

wordnet_terms_y = [
    'yacca',
    'yacht',
    'yachting',
    'yachts',
    'yachtsman',
    'yachtswoman',
    'yack',
    'yafo',
    'yagi',
    'yahi',
    'yahoo',
    'yahoos',
    'yahve',
    'yahveh',
    'yahwe',
    'yahweh',
    'yak',
    'yakima',
    'yakking',
    'yaks',
    'yakut',
    'yakuza',
    'yale',
    'yalta',
    'yaltopya',
    'yalu',
    'yam',
    'yama',
    'yamaltu',
    'yamamoto',
    'yamani',
    'yammer',
    'yamoussukro',
    'yams',
    'yana',
    'yanan',
    'yang',
    'yangon',
    'yangtse',
    'yangtze',
    'yank',
    'yanked',
    'yankee',
    'yankees',
    'yanker',
    'yanquapin',
    'yaounde',
    'yap',
    'yard',
    'yardage',
    'yardarm',
    'yardbird',
    'yarder',
    'yardgrass',
    'yardie',
    'yardman',
    'yardmaster',
    'yards',
    'yardstick',
    'yarmelke',
    'yarmulka',
    'yarmulke',
    'yarn',
    'yarns',
    'yarrow',
    'yashmac',
    'yashmak',
    'yasser',
    'yastrzemski',
    'yataghan',
    'yatobyo',
    'yaup',
    'yautia',
    'yavapai',
    'yaw',
    'yawed',
    'yawing',
    'yawl',
    'yawn',
    'yawned',
    'yawner',
    'yawning',
    'yawns',
    'yawp',
    'yaws',
    'yay',
    'yazoo',
    'yb',
    'ybit',
    'ye',
    'yea',
    'year',
    'yearbook',
    'yearling',
    'yearlong',
    'yearly',
    'yearn',
    'yearner',
    'yearning',
    'years',
    'yeas',
    'yeast',
    'yeastlike',
    'yeasts',
    'yeasty',
    'yeats',
    'yeatsian',
    'yeddo',
    'yedo',
    'yekaterinoslav',
    'yell',
    'yelled',
    'yeller',
    'yelling',
    'yellow',
    'yellowbird',
    'yellowcake',
    'yellowed',
    'yellower',
    'yellowfin',
    'yellowhammer',
    'yellowing',
    'yellowish',
    'yellowknife',
    'yellowlegs',
    'yellowness',
    'yellows',
    'yellowstone',
    'yellowtail',
    'yellowthroat',
    'yellowthroats',
    'yellowwood',
    'yellowwoods',
    'yells',
    'yelp',
    'yelping',
    'yemen',
    'yemeni',
    'yen',
    'yenisei',
    'yeniseian',
    'yenisey',
    'yenta',
    'yeoman',
    'yeomanry',
    'yerba',
    'yerevan',
    'yerkes',
    'yersin',
    'yersinia',
    'yerupaja',
    'yes',
    'yeshiva',
    'yeshivah',
    'yesterday',
    'yesteryear',
    'yet',
    'yeti',
    'yevtushenko',
    'yew',
    'yews',
    'yezo',
    'ygdrasil',
    'yggdrasil',
    'yhvh',
    'yhwh',
    'yi',
    'yib',
    'yibit',
    'yid',
    'yiddish',
    'yield',
    'yielded',
    'yielder',
    'yielding',
    'yields',
    'yin',
    'yip',
    'yips',
    'yisrael',
    'ylem',
    'ymir',
    'yob',
    'yobbo',
    'yobibit',
    'yobibyte',
    'yobo',
    'yodel',
    'yodeling',
    'yodeller',
    'yodh',
    'yoga',
    'yogacara',
    'yoghourt',
    'yoghurt',
    'yogi',
    'yogic',
    'yogistic',
    'yogurt',
    'yoke',
    'yokel',
    'yokelish',
    'yokohama',
    'yokuts',
    'yolk',
    'yolks',
    'yom',
    'yon',
    'yonder',
    'yore',
    'york',
    'yorker',
    'yorkshire',
    'yorktown',
    'yoruba',
    'yosemite',
    'yottabit',
    'yottabyte',
    'you',
    'young',
    'younger',
    'youngest',
    'youngish',
    'youngness',
    'youngster',
    'youngsters',
    'youngstown',
    'younker',
    'your',
    'yourself',
    'youth',
    'youthful',
    'youthfulness',
    'youths',
    'yowl',
    'yowling',
    'ypres',
    'yquem',
    'yr',
    'ytterbite',
    'ytterbium',
    'yttrium',
    'yuan',
    'yucatan',
    'yucatec',
    'yucateco',
    'yucca',
    'yucky',
    'yue',
    'yugoslav',
    'yugoslavia',
    'yugoslavian',
    'yukawa',
    'yukon',
    'yule',
    'yuletide',
    'yuma',
    'yuman',
    'yummy',
    'yung',
    'yunnan',
    'yuppie',
    'yurt']




#!/usr/bin/env python
# -*- coding: UTF-8 -*-

# pylint:disable=bad-whitespace
# pylint:disable=line-too-long
# pylint:disable=too-many-lines
# pylint:disable=invalid-name

# #########################################################
#
#       ************** !! WARNING !! ***************
#       ******* THIS FILE WAS AUTO-GENERATED *******
#       ********* DO NOT MODIFY THIS FILE **********
#
# #########################################################

wordnet_terms_z_provenance = {
    'action': ['router.py',
               'plac_core.py',
               'csv2py_orchestrator.py',
               'wordnet2py.py',
               'csv_list_writer.py',
               'common_utils.py'],
    'source': 'resources/data/csv/wordnet.csv',
    'time': '2022-05-17 17:00:36.244958'}

wordnet_terms_z = [
    'zaar',
    'zabaglione',
    'zabrze',
    'zacharias',
    'zachary',
    'zaftig',
    'zag',
    'zaglossus',
    'zagreb',
    'zaharias',
    'zaire',
    'zairean',
    'zairese',
    'zakat',
    'zalcitabine',
    'zalophus',
    'zama',
    'zaman',
    'zamang',
    'zambezi',
    'zambia',
    'zambian',
    'zamboni',
    'zamboorak',
    'zamburak',
    'zamburek',
    'zamia',
    'zamiaceae',
    'zamias',
    'zane',
    'zangwill',
    'zannichellia',
    'zannichelliaceae',
    'zantac',
    'zantedeschia',
    'zanthoxylum',
    'zanuck',
    'zany',
    'zanzibar',
    'zap',
    'zapata',
    'zapodidae',
    'zapotec',
    'zapotecan',
    'zapper',
    'zaps',
    'zapus',
    'zaragoza',
    'zarathustra',
    'zarf',
    'zaria',
    'zarontin',
    'zarpanit',
    'zarqa',
    'zayin',
    'zb',
    'zbit',
    'zdv',
    'zea',
    'zeal',
    'zealand',
    'zealander',
    'zealot',
    'zealotry',
    'zealous',
    'zealously',
    'zeaxanthin',
    'zebibit',
    'zebibits',
    'zebibyte',
    'zebibytes',
    'zebra',
    'zebrawood',
    'zebu',
    'zechariah',
    'zed',
    'zedong',
    'zee',
    'zeeman',
    'zeidae',
    'zeitgeist',
    'zen',
    'zenaidura',
    'zend',
    'zenith',
    'zenithal',
    'zeno',
    'zeolite',
    'zeomorphi',
    'zep',
    'zephaniah',
    'zephyr',
    'zeppelin',
    'zeppo',
    'zero',
    'zeroed',
    'zeros',
    'zeroth',
    'zest',
    'zestful',
    'zestfulness',
    'zestril',
    'zesty',
    'zeta',
    'zetland',
    'zettabit',
    'zettabits',
    'zettabyte',
    'zettabytes',
    'zeugma',
    'zeus',
    'zhou',
    'zhu',
    'zhuang',
    'zhukov',
    'zib',
    'zibit',
    'zidovudine',
    'ziegfeld',
    'ziegler',
    'zig',
    'zigadene',
    'zigadenus',
    'ziggurat',
    'zigzag',
    'zigzags',
    'zikkurat',
    'zikurat',
    'zilch',
    'zill',
    'zillion',
    'zimbabwe',
    'zimbabwean',
    'zimbalist',
    'zimmer',
    'zinacef',
    'zinc',
    'zinfandel',
    'zing',
    'zinger',
    'zingiber',
    'zingiberaceae',
    'zinjanthropus',
    'zinkenite',
    'zinnemann',
    'zinnia',
    'zinnwaldite',
    'zinsser',
    'zinzendorf',
    'zion',
    'zionism',
    'zionist',
    'zip',
    'ziphiidae',
    'zipped',
    'zipper',
    'zippo',
    'zippy',
    'zirbanit',
    'zircon',
    'zirconia',
    'zirconium',
    'zit',
    'zither',
    'zithern',
    'zithers',
    'zithromax',
    'ziti',
    'zizania',
    'ziziphus',
    'zizz',
    'zloty',
    'zn',
    'zoanthropy',
    'zoarces',
    'zoarcidae',
    'zocor',
    'zodiac',
    'zodiacal',
    'zoftig',
    'zoic',
    'zoisia',
    'zola',
    'zolaesque',
    'zoloft',
    'zomba',
    'zombi',
    'zombie',
    'zona',
    'zonal',
    'zonary',
    'zone',
    'zones',
    'zoning',
    'zonked',
    'zonotrichia',
    'zonula',
    'zonule',
    'zoo',
    'zooerastia',
    'zooerasty',
    'zooflagellate',
    'zooid',
    'zooids',
    'zoolatry',
    'zoological',
    'zoologist',
    'zoologists',
    'zoology',
    'zoom',
    'zoomastigina',
    'zoomastigote',
    'zoomed',
    'zoomorphism',
    'zoonosis',
    'zoonotic',
    'zoophagous',
    'zoophilia',
    'zoophilism',
    'zoophobia',
    'zoophyte',
    'zooplankton',
    'zoopsia',
    'zoospore',
    'zoospores',
    'zootoxin',
    'zori',
    'zoril',
    'zoroaster',
    'zoroastrian',
    'zoroastrianism',
    'zoster',
    'zostera',
    'zosteraceae',
    'zovirax',
    'zoysia',
    'zr',
    'zsigmondy',
    'zu',
    'zubird',
    'zucchini',
    'zuider',
    'zukerman',
    'zulu',
    'zulus',
    'zumbooruck',
    'zumbooruk',
    'zuni',
    'zurich',
    'zurvan',
    'zurvanism',
    'zweig',
    'zwieback',
    'zwingli',
    'zworykin',
    'zydeco',
    'zygnema',
    'zygnemales',
    'zygnemataceae',
    'zygnematales',
    'zygocactus',
    'zygodactyl',
    'zygoma',
    'zygomatic',
    'zygomorphic',
    'zygomorphous',
    'zygomycetes',
    'zygomycota',
    'zygomycotina',
    'zygophyllaceae',
    'zygophyllum',
    'zygoptera',
    'zygospore',
    'zygospores',
    'zygote',
    'zygotene',
    'zygotic',
    'zyloprim',
    'zymase',
    'zymogen',
    'zymoid',
    'zymology',
    'zymolysis',
    'zymolytic',
    'zymosis',
    'zymotic',
    'zymurgy',
    'zyrian']




#!/usr/bin/env python
# -*- coding: UTF-8 -*-

# pylint:disable=bad-whitespace
# pylint:disable=line-too-long
# pylint:disable=too-many-lines
# pylint:disable=invalid-name

# #########################################################
#
#       ************** !! WARNING !! ***************
#       ******* THIS FILE WAS AUTO-GENERATED *******
#       ********* DO NOT MODIFY THIS FILE **********
#
# #########################################################

wordnet_terms_w_provenance = {
    'action': ['router.py',
               'plac_core.py',
               'csv2py_orchestrator.py',
               'wordnet2py.py',
               'csv_list_writer.py',
               'common_utils.py'],
    'source': 'resources/data/csv/wordnet.csv',
    'time': '2022-05-17 17:00:36.241458'}

wordnet_terms_w = [
    'wa',
    'wabash',
    'wac',
    'wacko',
    'wacky',
    'waco',
    'wad',
    'wadding',
    'waddle',
    'waddler',
    'waddlers',
    'waddling',
    'wade',
    'waded',
    'wader',
    'waders',
    'wadi',
    'wading',
    'wads',
    'wafer',
    'wafers',
    'waffle',
    'waffler',
    'waft',
    'wafted',
    'wafture',
    'wag',
    'wage',
    'waged',
    'wager',
    'wagered',
    'wagerer',
    'wagers',
    'wages',
    'wagged',
    'waggery',
    'waggish',
    'waggishness',
    'waggle',
    'waggon',
    'waggoner',
    'waggonwright',
    'waging',
    'wagner',
    'wagnerian',
    'wagon',
    'wagoner',
    'wagons',
    'wagonwright',
    'wagram',
    'wagtail',
    'wagtails',
    'wahabi',
    'wahabism',
    'wahhabi',
    'wahhabism',
    'wahoo',
    'wahoos',
    'wahunsonacock',
    'wahvey',
    'waif',
    'waikiki',
    'wail',
    'wailed',
    'wailer',
    'wailful',
    'wailing',
    'wails',
    'wain',
    'wainscot',
    'wainscoted',
    'wainscoting',
    'wainscotting',
    'wainwright',
    'waist',
    'waistband',
    'waistcloth',
    'waistcoat',
    'waistline',
    'wait',
    'waite',
    'waited',
    'waiter',
    'waiters',
    'waiting',
    'waitress',
    'waitresses',
    'waits',
    'waive',
    'waiver',
    'wajda',
    'wakashan',
    'wake',
    'wakeboard',
    'waked',
    'wakeful',
    'wakefulness',
    'wakeless',
    'waken',
    'wakening',
    'wakens',
    'waker',
    'wakes',
    'waking',
    'walapai',
    'walbiri',
    'wald',
    'waldenses',
    'waldheim',
    'waldmeister',
    'waldo',
    'wale',
    'wales',
    'walesa',
    'walhalla',
    'walk',
    'walkabout',
    'walkaway',
    'walked',
    'walker',
    'walking',
    'walkingstick',
    'walkman',
    'walkout',
    'walkover',
    'walks',
    'walkway',
    'wall',
    'wallabies',
    'wallaby',
    'wallace',
    'wallah',
    'wallboard',
    'walled',
    'wallenstein',
    'waller',
    'wallet',
    'walleye',
    'walleyed',
    'wallflower',
    'wallis',
    'walloon',
    'walloons',
    'wallop',
    'walloper',
    'walloping',
    'wallow',
    'wallowing',
    'wallpaper',
    'wallpaperer',
    'walls',
    'wally',
    'walnut',
    'walnuts',
    'walpole',
    'walrus',
    'walruses',
    'walt',
    'walter',
    'walton',
    'waltz',
    'waltzer',
    'waltzes',
    'waltzing',
    'wamble',
    'wampanoag',
    'wampee',
    'wampum',
    'wampumpeag',
    'wan',
    'wanamaker',
    'wand',
    'wandala',
    'wander',
    'wandered',
    'wanderer',
    'wandering',
    'wanderings',
    'wanderlust',
    'wanders',
    'wandflower',
    'wands',
    'wane',
    'waned',
    'wangle',
    'wangler',
    'wangling',
    'waning',
    'wank',
    'wanker',
    'wannabe',
    'wannabee',
    'wanness',
    'wannsee',
    'want',
    'wanted',
    'wanter',
    'wanting',
    'wanton',
    'wantonly',
    'wantonness',
    'wants',
    'wapiti',
    'war',
    'waratah',
    'waratahs',
    'warble',
    'warbler',
    'warblers',
    'warburg',
    'ward',
    'warded',
    'warden',
    'wardenship',
    'warder',
    'wardership',
    'warding',
    'wardress',
    'wardrobe',
    'wardroom',
    'ware',
    'warehouse',
    'warehouseman',
    'warehouser',
    'warehouses',
    'warehousing',
    'wares',
    'warfare',
    'warfarin',
    'warfield',
    'warhead',
    'warheads',
    'warhol',
    'warhorse',
    'warily',
    'wariness',
    'warji',
    'warlike',
    'warlock',
    'warlord',
    'warlpiri',
    'warm',
    'warmed',
    'warmer',
    'warmest',
    'warmhearted',
    'warmheartedness',
    'warming',
    'warmly',
    'warmness',
    'warmonger',
    'warmongering',
    'warmongers',
    'warms',
    'warmth',
    'warn',
    'warned',
    'warner',
    'warning',
    'warnings',
    'warns',
    'warp',
    'warpath',
    'warped',
    'warping',
    'warplane',
    'warragal',
    'warrant',
    'warrantee',
    'warranter',
    'warranting',
    'warrantor',
    'warrants',
    'warranty',
    'warren',
    'warrener',
    'warrigal',
    'warring',
    'warrior',
    'warriorlike',
    'warriors',
    'wars',
    'warsaw',
    'warship',
    'warships',
    'warszawa',
    'wart',
    'warthog',
    'warthogs',
    'wartime',
    'wartimes',
    'wartlike',
    'warts',
    'wartweed',
    'wartwort',
    'warty',
    'warwick',
    'wary',
    'was',
    'wasabi',
    'wash',
    'washable',
    'washables',
    'washbasin',
    'washboard',
    'washboards',
    'washbowl',
    'washcloth',
    'washday',
    'washed',
    'washer',
    'washerman',
    'washerwoman',
    'washes',
    'washhouse',
    'washing',
    'washington',
    'washingtonian',
    'washout',
    'washrag',
    'washroom',
    'washstand',
    'washtub',
    'washup',
    'washwoman',
    'washy',
    'wasp',
    'waspish',
    'wasps',
    'wassail',
    'wassailer',
    'wassermann',
    'wastage',
    'waste',
    'wastebasket',
    'wastebin',
    'wasted',
    'wasteful',
    'wastefully',
    'wastefulness',
    'wasteland',
    'waster',
    'wastes',
    'wastewater',
    'wasteweir',
    'wasteyard',
    'wasting',
    'wastrel',
    'watch',
    'watchband',
    'watchdog',
    'watchdogs',
    'watched',
    'watcher',
    'watchers',
    'watches',
    'watchful',
    'watchfulness',
    'watching',
    'watchmaker',
    'watchman',
    'watchstrap',
    'watchtower',
    'watchword',
    'water',
    'waterbird',
    'waterborne',
    'waterbuck',
    'waterbucks',
    'waterbury',
    'watercannon',
    'watercolor',
    'watercolorist',
    'watercolors',
    'watercolour',
    'watercolourist',
    'watercourse',
    'watercourses',
    'watercraft',
    'watercress',
    'waterdog',
    'watered',
    'waterer',
    'waterfall',
    'waterfalls',
    'waterfinder',
    'waterford',
    'waterfowl',
    'waterfront',
    'watergate',
    'wateriness',
    'watering',
    'waterleaf',
    'waterless',
    'waterlessness',
    'waterline',
    'waterlines',
    'waterlogged',
    'waterloo',
    'waterman',
    'watermark',
    'watermeal',
    'watermelon',
    'watermelons',
    'waterpower',
    'waterproof',
    'waterproofed',
    'waterproofing',
    'waters',
    'waterscape',
    'watershed',
    'waterside',
    'waterskin',
    'waterspout',
    'watertight',
    'watertown',
    'waterway',
    'waterways',
    'waterweed',
    'waterwheel',
    'waterworks',
    'waterworn',
    'watery',
    'wats',
    'watson',
    'watt',
    'wattage',
    'watteau',
    'wattle',
    'wattles',
    'wattmeter',
    'watts',
    'watusi',
    'watutsi',
    'waugh',
    'waul',
    'wausau',
    'wave',
    'waveband',
    'waved',
    'waveform',
    'wavefront',
    'waveguide',
    'wavelength',
    'wavelengths',
    'wavelet',
    'wavelike',
    'wavell',
    'waver',
    'waverer',
    'wavering',
    'waves',
    'waviness',
    'waving',
    'wavy',
    'waw',
    'wawl',
    'wax',
    'waxberry',
    'waxed',
    'waxen',
    'waxes',
    'waxflower',
    'waxiness',
    'waxing',
    'waxlike',
    'waxmallow',
    'waxwing',
    'waxwings',
    'waxwork',
    'waxworks',
    'waxy',
    'waxycap',
    'way',
    'waybill',
    'wayfarer',
    'wayfaring',
    'wayland',
    'waylay',
    'wayne',
    'ways',
    'wayside',
    'wayward',
    'wb',
    'wbc',
    'wbn',
    'wbs',
    'wc',
    'we',
    'weak',
    'weaken',
    'weakened',
    'weakener',
    'weakening',
    'weakens',
    'weaker',
    'weakest',
    'weakfish',
    'weakling',
    'weakly',
    'weakness',
    'weal',
    'weald',
    'weals',
    'wealth',
    'wealthiness',
    'wealthy',
    'wean',
    'weaned',
    'weaning',
    'weapon',
    'weaponed',
    'weaponize',
    'weaponless',
    'weaponry',
    'weapons',
    'wear',
    'wearable',
    'wearer',
    'wearied',
    'weariness',
    'wearing',
    'wearisome',
    'wears',
    'weary',
    'wearying',
    'weasel',
    'weasels',
    'weather',
    'weatherboard',
    'weatherboarding',
    'weathercock',
    'weathered',
    'weatherglass',
    'weathering',
    'weatherliness',
    'weatherly',
    'weatherman',
    'weatherproof',
    'weatherproofing',
    'weatherstrip',
    'weatherstripped',
    'weatherstripping',
    'weathervane',
    'weatherworn',
    'weave',
    'weaver',
    'weaverbird',
    'weaverbirds',
    'weaves',
    'weaving',
    'web',
    'webb',
    'webbed',
    'webber',
    'webbing',
    'webby',
    'webcam',
    'weber',
    'webfoot',
    'weblike',
    'webmaster',
    'webpage',
    'webs',
    'website',
    'webster',
    'webworm',
    'webworms',
    'wed',
    'wedded',
    'weddell',
    'wedding',
    'weddings',
    'wedel',
    'wedge',
    'wedged',
    'wedges',
    'wedgie',
    'wedgwood',
    'wedlock',
    'wednesday',
    'wee',
    'weed',
    'weeded',
    'weeder',
    'weeding',
    'weedkiller',
    'weedless',
    'weeds',
    'weedy',
    'week',
    'weekday',
    'weekdays',
    'weekend',
    'weekender',
    'weekends',
    'weeklong',
    'weekly',
    'weeknight',
    'weeks',
    'weeness',
    'weenie',
    'weensy',
    'weeny',
    'weep',
    'weeper',
    'weepiness',
    'weeping',
    'weeps',
    'weepy',
    'weevil',
    'weevils',
    'weevily',
    'weewee',
    'weft',
    'wegener',
    'wehrmacht',
    'wei',
    'weigela',
    'weigh',
    'weighbridge',
    'weighed',
    'weigher',
    'weighing',
    'weighs',
    'weight',
    'weighted',
    'weightiness',
    'weighting',
    'weightless',
    'weightlessness',
    'weightlift',
    'weightlifter',
    'weightlifters',
    'weightlifting',
    'weights',
    'weighty',
    'weil',
    'weill',
    'weimar',
    'weimaraner',
    'weinberg',
    'weir',
    'weird',
    'weirdie',
    'weirdness',
    'weirdo',
    'weirdy',
    'weisenheimer',
    'weismann',
    'weissbier',
    'weisshorn',
    'weizenbier',
    'weizenbock',
    'weizmann',
    'weka',
    'welch',
    'welcher',
    'welcome',
    'welcomed',
    'welcomer',
    'welcomes',
    'welcoming',
    'weld',
    'welded',
    'welder',
    'welders',
    'welding',
    'weldment',
    'welds',
    'welfare',
    'welfarist',
    'welkin',
    'well',
    'wellbeing',
    'wellborn',
    'welled',
    'wellerism',
    'welles',
    'wellhead',
    'welling',
    'wellington',
    'wellness',
    'wellpoint',
    'wells',
    'wellspring',
    'welsh',
    'welsher',
    'welshman',
    'welt',
    'weltanschauung',
    'welter',
    'weltered',
    'welterweight',
    'weltschmerz',
    'welty',
    'welwitschia',
    'welwitschiaceae',
    'wembley',
    'wen',
    'wench',
    'wencher',
    'wend',
    'wendell',
    'went',
    'wept',
    'were',
    'werewolf',
    'werfel',
    'werner',
    'wernicke',
    'weser',
    'wesley',
    'wesleyan',
    'wesleyanism',
    'wesleyism',
    'wessex',
    'west',
    'westbound',
    'westcott',
    'wester',
    'westerly',
    'western',
    'westerner',
    'westerners',
    'westernisation',
    'westernise',
    'westernization',
    'westernize',
    'westernized',
    'westernmost',
    'westinghouse',
    'westminster',
    'westmost',
    'weston',
    'westphalia',
    'westside',
    'westward',
    'wet',
    'wetback',
    'wether',
    'wetland',
    'wetlands',
    'wetness',
    'wetnurse',
    'wets',
    'wetted',
    'wetter',
    'wetting',
    'whack',
    'whacked',
    'whacker',
    'whacking',
    'whacko',
    'whacky',
    'whale',
    'whaleboat',
    'whalebone',
    'whaler',
    'whalers',
    'whales',
    'whalesucker',
    'whaling',
    'wham',
    'whammy',
    'whang',
    'whap',
    'wharf',
    'wharfage',
    'wharfed',
    'wharton',
    'wharves',
    'what',
    'whatchamacallit',
    'whatchamacallum',
    'whatever',
    'whatnot',
    'whatsis',
    'whatsoever',
    'whatver',
    'wheal',
    'wheat',
    'wheatear',
    'wheatears',
    'wheaten',
    'wheatfield',
    'wheatflake',
    'wheatgrass',
    'wheatley',
    'wheatstone',
    'wheatworm',
    'wheedle',
    'wheedler',
    'wheedling',
    'wheel',
    'wheelbarrow',
    'wheelbase',
    'wheelchair',
    'wheeled',
    'wheeler',
    'wheelhouse',
    'wheeling',
    'wheelless',
    'wheels',
    'wheelwork',
    'wheelwright',
    'wheeze',
    'wheeziness',
    'wheezing',
    'wheezy',
    'whelk',
    'whelks',
    'whelm',
    'whelp',
    'when',
    'whenever',
    'where',
    'whereabouts',
    'whereas',
    'whereby',
    'wherefore',
    'wherein',
    'wherewithal',
    'wherry',
    'whet',
    'whether',
    'whetstone',
    'whey',
    'which',
    'whicker',
    'whidah',
    'whiff',
    'whiffed',
    'whiffer',
    'whiffletree',
    'whiffletrees',
    'whig',
    'whigs',
    'while',
    'whim',
    'whimper',
    'whims',
    'whimsey',
    'whimsical',
    'whimsicality',
    'whimsically',
    'whimsy',
    'whin',
    'whinberry',
    'whinchat',
    'whine',
    'whiner',
    'whiney',
    'whining',
    'whiningly',
    'whinny',
    'whinstone',
    'whiny',
    'whip',
    'whipcord',
    'whiplash',
    'whiplike',
    'whipped',
    'whipper',
    'whippersnapper',
    'whippet',
    'whipping',
    'whippletree',
    'whippoorwill',
    'whippy',
    'whips',
    'whipsaw',
    'whipsnake',
    'whipstitch',
    'whipstitching',
    'whiptail',
    'whiptails',
    'whir',
    'whirl',
    'whirlaway',
    'whirled',
    'whirler',
    'whirligig',
    'whirling',
    'whirlpool',
    'whirls',
    'whirlwind',
    'whirlybird',
    'whirr',
    'whirring',
    'whish',
    'whished',
    'whishing',
    'whisk',
    'whisked',
    'whisker',
    'whiskered',
    'whiskerless',
    'whiskers',
    'whiskery',
    'whiskey',
    'whiskeys',
    'whiskies',
    'whisky',
    'whisper',
    'whispered',
    'whisperer',
    'whispering',
    'whist',
    'whistle',
    'whistleblower',
    'whistleblowers',
    'whistled',
    'whistler',
    'whistles',
    'whistlestop',
    'whistling',
    'whit',
    'white',
    'whitebait',
    'whitecap',
    'whitecup',
    'whiteface',
    'whitefish',
    'whitefishes',
    'whiteflies',
    'whitefly',
    'whitehall',
    'whitehead',
    'whitehorse',
    'whitelash',
    'whiten',
    'whitened',
    'whitener',
    'whiteness',
    'whitening',
    'whiteout',
    'whiter',
    'whites',
    'whitetail',
    'whitethorn',
    'whitethroat',
    'whitewash',
    'whitewashed',
    'whitewater',
    'whitewood',
    'whitey',
    'whiting',
    'whitings',
    'whitish',
    'whitlavia',
    'whitlow',
    'whitlows',
    'whitlowwort',
    'whitlowworts',
    'whitman',
    'whitmonday',
    'whitney',
    'whitsun',
    'whitsunday',
    'whitsuntide',
    'whittier',
    'whittle',
    'whittler',
    'whittles',
    'whittling',
    'whitweek',
    'whiz',
    'whizbang',
    'whizz',
    'whizzbang',
    'whizzing',
    'who',
    'whodunit',
    'whoever',
    'whole',
    'wholehearted',
    'wholeheartedly',
    'wholeheartedness',
    'wholemeal',
    'wholeness',
    'wholesale',
    'wholesaler',
    'wholesalers',
    'wholesome',
    'wholesomeness',
    'wholly',
    'whom',
    'whomp',
    'whoop',
    'whooped',
    'whoopee',
    'whooper',
    'whooping',
    'whoosh',
    'whooshed',
    'whooshing',
    'whop',
    'whopper',
    'whopping',
    'whore',
    'whored',
    'whoredom',
    'whorehouse',
    'whoremaster',
    'whoremonger',
    'whores',
    'whoreson',
    'whorl',
    'whorled',
    'whorls',
    'whorlywort',
    'whortleberry',
    'whose',
    'why',
    'whydah',
    'whydahs',
    'whys',
    'wi',
    'wicca',
    'wiccan',
    'wichita',
    'wick',
    'wicked',
    'wickedness',
    'wicker',
    'wickerwork',
    'wicket',
    'wickiup',
    'wickliffe',
    'wickup',
    'wiclif',
    'wicopy',
    'wide',
    'wideband',
    'widely',
    'widen',
    'widened',
    'wideness',
    'widening',
    'widens',
    'wider',
    'widespread',
    'widest',
    'widgeon',
    'widget',
    'widow',
    'widowed',
    'widower',
    'widowhood',
    'widowman',
    'width',
    'widths',
    'wieland',
    'wield',
    'wielded',
    'wielding',
    'wields',
    'wieldy',
    'wiener',
    'wienerwurst',
    'wiesbaden',
    'wiesel',
    'wiesenboden',
    'wiesenthal',
    'wife',
    'wifelike',
    'wifely',
    'wiffle',
    'wifi',
    'wig',
    'wigeon',
    'wigged',
    'wigging',
    'wiggle',
    'wiggler',
    'wiggliness',
    'wiggling',
    'wiggly',
    'wight',
    'wightiana',
    'wigless',
    'wigmaker',
    'wigner',
    'wigs',
    'wigwag',
    'wigwam',
    'wikiup',
    'wilbur',
    'wild',
    'wildcat',
    'wildcats',
    'wildcatter',
    'wilde',
    'wildebeest',
    'wilder',
    'wilderness',
    'wildest',
    'wildfire',
    'wildflower',
    'wildflowers',
    'wildfowl',
    'wilding',
    'wildlife',
    'wildly',
    'wildness',
    'wile',
    'wilets',
    'wilful',
    'wilfully',
    'wilfulness',
    'wilhelm',
    'wiliness',
    'wilkes',
    'wilkins',
    'wilkinson',
    'will',
    'willa',
    'willamette',
    'willard',
    'willebrand',
    'willed',
    'willet',
    'willful',
    'willfully',
    'willfulness',
    'william',
    'williams',
    'williamstown',
    'willies',
    'willing',
    'willingly',
    'willingness',
    'willis',
    'willow',
    'willowherb',
    'willows',
    'willowware',
    'willowy',
    'willpower',
    'wills',
    'wilmington',
    'wilmut',
    'wilno',
    'wilson',
    'wilsonian',
    'wilt',
    'wilted',
    'wilting',
    'wilton',
    'wily',
    'wimble',
    'wimbledon',
    'wimp',
    'wimpish',
    'wimple',
    'wimpy',
    'win',
    'wince',
    'winced',
    'wincey',
    'winceyette',
    'winch',
    'winchester',
    'winckelmann',
    'wind',
    'windage',
    'windaus',
    'windbag',
    'windblown',
    'windbreak',
    'windbreaker',
    'windburn',
    'windburned',
    'windburnt',
    'windcheater',
    'winded',
    'winder',
    'windfall',
    'windflower',
    'windhoek',
    'windily',
    'windiness',
    'winding',
    'windjammer',
    'windlass',
    'windless',
    'windlessness',
    'windmill',
    'window',
    'windowpane',
    'windows',
    'windowsill',
    'windpipe',
    'winds',
    'windscreen',
    'windshield',
    'windsock',
    'windsor',
    'windstorm',
    'windsurf',
    'windswept',
    'windtalker',
    'windup',
    'windward',
    'windy',
    'wine',
    'wineberry',
    'wined',
    'wineglass',
    'winemaker',
    'winemaking',
    'winepress',
    'winery',
    'wines',
    'winesap',
    'wineskin',
    'winey',
    'winfield',
    'winfred',
    'wing',
    'wingback',
    'winged',
    'winger',
    'wingless',
    'winglike',
    'wingman',
    'wings',
    'wingspan',
    'wingspread',
    'wingstem',
    'wining',
    'wink',
    'winked',
    'winker',
    'winking',
    'winkle',
    'winkled',
    'winks',
    'winless',
    'winnebago',
    'winner',
    'winners',
    'winning',
    'winnings',
    'winnipeg',
    'winnow',
    'winnowed',
    'winnowing',
    'wino',
    'wins',
    'winslow',
    'winsome',
    'winsomeness',
    'winston',
    'winter',
    'wintera',
    'winteraceae',
    'winterana',
    'winterberry',
    'wintered',
    'wintergreen',
    'winterise',
    'winterize',
    'winters',
    'wintertime',
    'wintery',
    'winthrop',
    'wintry',
    'wintun',
    'winy',
    'wipe',
    'wiped',
    'wipeout',
    'wiper',
    'wipes',
    'wiping',
    'wire',
    'wired',
    'wirehair',
    'wireless',
    'wireman',
    'wirer',
    'wires',
    'wiretap',
    'wiretapper',
    'wiretaps',
    'wirework',
    'wireworm',
    'wiriness',
    'wiring',
    'wiry',
    'wisconsin',
    'wisconsinite',
    'wisdom',
    'wise',
    'wiseacre',
    'wisecrack',
    'wised',
    'wisely',
    'wiseness',
    'wisenheimer',
    'wisent',
    'wiser',
    'wish',
    'wishbone',
    'wished',
    'wishes',
    'wishful',
    'wishfulness',
    'wishing',
    'wisp',
    'wisplike',
    'wisps',
    'wispy',
    'wistaria',
    'wister',
    'wisteria',
    'wistful',
    'wistfulness',
    'wit',
    'witch',
    'witchcraft',
    'witchery',
    'witches',
    'witchgrass',
    'witching',
    'witchlike',
    'with',
    'withdraw',
    'withdrawal',
    'withdrawals',
    'withdrawer',
    'withdrawing',
    'withdrawn',
    'withdrawnness',
    'withdraws',
    'withdrew',
    'withe',
    'wither',
    'withered',
    'withering',
    'withers',
    'witherspoon',
    'withheld',
    'withhold',
    'withholder',
    'withholding',
    'within',
    'without',
    'withstand',
    'withstander',
    'withstanders',
    'withstanding',
    'withstands',
    'withstood',
    'withy',
    'witless',
    'witloof',
    'witness',
    'witnessed',
    'witnesser',
    'witnesses',
    'witnessing',
    'wits',
    'wittgenstein',
    'wittgensteinian',
    'witticism',
    'wittiness',
    'witting',
    'wittol',
    'witty',
    'witwatersrand',
    'wive',
    'wivern',
    'wives',
    'wiz',
    'wizard',
    'wizardly',
    'wizardry',
    'wizen',
    'wizened',
    'wlan',
    'wmd',
    'wmo',
    'wnw',
    'woad',
    'woadwaxen',
    'wobble',
    'wobbled',
    'wobbler',
    'wobbles',
    'wobbling',
    'wobbly',
    'wodan',
    'wodehouse',
    'woden',
    'woe',
    'woebegone',
    'woeful',
    'woefully',
    'woefulness',
    'wog',
    'wok',
    'woke',
    'wold',
    'wolf',
    'wolfbane',
    'wolfe',
    'wolfed',
    'wolff',
    'wolffia',
    'wolffiella',
    'wolffish',
    'wolffishes',
    'wolfgang',
    'wolfhound',
    'wolfish',
    'wolflike',
    'wolfman',
    'wolfram',
    'wolframite',
    'wolfsbane',
    'wollaston',
    'wollastonite',
    'wollemi',
    'wollstonecraft',
    'wolof',
    'wolverine',
    'wolves',
    'woman',
    'womanhood',
    'womanise',
    'womaniser',
    'womanish',
    'womanishness',
    'womanize',
    'womanizer',
    'womanizing',
    'womankind',
    'womanlike',
    'womanliness',
    'womanly',
    'womb',
    'wombat',
    'wombats',
    'women',
    'won',
    'wonder',
    'wonderberry',
    'wondered',
    'wonderer',
    'wonderful',
    'wonderfully',
    'wonderfulness',
    'wonderland',
    'wonderment',
    'wonders',
    'wonderworking',
    'wondrous',
    'wong',
    'wonk',
    'wonky',
    'wont',
    'wonted',
    'wonton',
    'woo',
    'wood',
    'woodbine',
    'woodborer',
    'woodbury',
    'woodcarver',
    'woodcarving',
    'woodchuck',
    'woodchucks',
    'woodcock',
    'woodcocks',
    'woodcraft',
    'woodcreeper',
    'woodcreepers',
    'woodcut',
    'woodcuts',
    'woodcutter',
    'wooded',
    'wooden',
    'woodenness',
    'woodenware',
    'woodfern',
    'woodgrain',
    'woodgraining',
    'woodhewer',
    'woodhewers',
    'woodhull',
    'woodiness',
    'woodland',
    'woodlands',
    'woodlet',
    'woodlice',
    'woodlouse',
    'woodman',
    'woodpecker',
    'woodpeckers',
    'woodpile',
    'woodrow',
    'woodruff',
    'woods',
    'woodscrew',
    'woodshed',
    'woodsia',
    'woodsiness',
    'woodsman',
    'woodstock',
    'woodsy',
    'woodward',
    'woodwardia',
    'woodwaxen',
    'woodwind',
    'woodwinds',
    'woodwork',
    'woodworker',
    'woodworking',
    'woodworm',
    'woody',
    'wooed',
    'wooer',
    'woof',
    'woofer',
    'wooing',
    'wool',
    'woolen',
    'woolens',
    'woolf',
    'woolgather',
    'woolgatherer',
    'woolgathering',
    'woollcott',
    'woollen',
    'woolley',
    'woolly',
    'woolsorter',
    'woolworth',
    'wooly',
    'woosh',
    'woozy',
    'wop',
    'worcester',
    'worcestershire',
    'word',
    'wordbook',
    'worded',
    'wordfinder',
    'wordiness',
    'wording',
    'wordless',
    'wordmonger',
    'wordnet',
    'wordplay',
    'words',
    'wordsmith',
    'wordsworth',
    'wordsworthian',
    'wordy',
    'wore',
    'work',
    'workable',
    'workaday',
    'workaholic',
    'workaholism',
    'workbag',
    'workbasket',
    'workbench',
    'workboard',
    'workbook',
    'workbox',
    'workday',
    'worked',
    'worker',
    'workers',
    'workfellow',
    'workflow',
    'workforce',
    'workhorse',
    'workhouse',
    'working',
    'workingman',
    'workings',
    'workload',
    'workman',
    'workmanlike',
    'workmanship',
    'workmate',
    'workmen',
    'workout',
    'workpiece',
    'workplace',
    'workroom',
    'works',
    'worksheet',
    'workshop',
    'workspace',
    'workstation',
    'workstations',
    'worktable',
    'workwear',
    'workweek',
    'world',
    'worldliness',
    'worldling',
    'worldly',
    'worlds',
    'worldwide',
    'worm',
    'wormcast',
    'wormhole',
    'wormlike',
    'worms',
    'wormseed',
    'wormwood',
    'wormy',
    'worn',
    'worried',
    'worrier',
    'worries',
    'worriment',
    'worrisome',
    'worry',
    'worrying',
    'worryingly',
    'worrywart',
    'worse',
    'worsen',
    'worsened',
    'worsening',
    'worship',
    'worshiped',
    'worshiper',
    'worshipful',
    'worshiping',
    'worshipped',
    'worshipper',
    'worshippers',
    'worshipping',
    'worships',
    'worst',
    'worsted',
    'wort',
    'worth',
    'worthful',
    'worthies',
    'worthiness',
    'worthless',
    'worthlessness',
    'worthwhile',
    'worthwhileness',
    'worthy',
    'wotan',
    'wouk',
    'would',
    'wound',
    'wounded',
    'wounding',
    'wounds',
    'woven',
    'wow',
    'wowed',
    'wpm',
    'wrack',
    'wraith',
    'wraithlike',
    'wrangle',
    'wrangler',
    'wrangling',
    'wrap',
    'wraparound',
    'wrapped',
    'wrapper',
    'wrapping',
    'wraps',
    'wrasse',
    'wrasses',
    'wrath',
    'wrathful',
    'wrawl',
    'wreak',
    'wreaking',
    'wreath',
    'wreathe',
    'wreck',
    'wreckage',
    'wrecked',
    'wrecker',
    'wreckfish',
    'wrecking',
    'wrecks',
    'wren',
    'wrench',
    'wrenched',
    'wrenching',
    'wrens',
    'wrest',
    'wrester',
    'wrestle',
    'wrestled',
    'wrestler',
    'wrestlers',
    'wrestling',
    'wretch',
    'wretched',
    'wretchedness',
    'wretches',
    'wrick',
    'wriggle',
    'wriggler',
    'wriggling',
    'wriggly',
    'wright',
    'wring',
    'wringer',
    'wrinkle',
    'wrinkled',
    'wrinkleless',
    'wrinkleproof',
    'wrinkles',
    'wrinkly',
    'wrist',
    'wristband',
    'wristlet',
    'wrists',
    'wristwatch',
    'writ',
    'write',
    'writer',
    'writers',
    'writes',
    'writhe',
    'writhed',
    'writhen',
    'writhing',
    'writing',
    'writings',
    'writs',
    'written',
    'wroclaw',
    'wrong',
    'wrongdoer',
    'wrongdoing',
    'wrongful',
    'wrongfully',
    'wrongfulness',
    'wrongheaded',
    'wrongly',
    'wrongness',
    'wrongs',
    'wrote',
    'wroth',
    'wrothful',
    'wrought',
    'wry',
    'wrymouth',
    'wryneck',
    'wrynecks',
    'ws',
    'wsw',
    'wtc',
    'wto',
    'wtv',
    'wu',
    'wuerzburg',
    'wuhan',
    'wulfenite',
    'wulfila',
    'wurlitzer',
    'wurtzite',
    'wurzburg',
    'wuss',
    'wv',
    'ww',
    'www',
    'wy',
    'wyat',
    'wyatt',
    'wycherley',
    'wyck',
    'wyclif',
    'wycliffe',
    'wye',
    'wyeth',
    'wykeham',
    'wykehamist',
    'wyler',
    'wylie',
    'wyllis',
    'wynette',
    'wynfrith',
    'wynnea',
    'wyoming',
    'wyomingite',
    'wyrd',
    'wysiwyg',
    'wyszynski',
    'wytensin',
    'wyvern']



#!/usr/bin/env python
# -*- coding: UTF-8 -*-
""" Add Wordnet Flag to Token """


from lingpatlab.utils.dmo import PorterStemmer

from lingpatlab.baseblock import BaseObject


class TokenParserPostProcess(BaseObject):
    """ Post Process an """

    __hyphens = {
        '\u058a': 'U+058A',
        '\u1806': 'U+1806',
        '\u2010': 'U+2010',
        '\u2011': 'U+2011',
        '\u2012': 'U+2012',
        '\u2013': 'U+2013',
        '\u2014': 'U+2014',
        '\u2015': 'U+2015',
        '\u2053': 'U+2053',
        '\u207b': 'U+207B',
        '\u208b': 'U+208B',
        '\u2212': 'U+2212',
        '\u2e3a': 'U+2E3A',
        '\u2e3b': 'U+2E3B',
        '\u301c': 'U+301C',
        '\u3030': 'U+3030',
        '\ufe58': 'U+FE58',
        '\ufe63': 'U+FE63',
        '\uff0d': 'U+FF0D'
    }

    __squotes = [
        '\u2019',
        '\u2018',
        '\u201b',
        '`'
    ]

    __dquotes = [
        '\u201c',
        '\u201d',
        '\u00ab',
        '\u00bb',
        '\u201e',
        '``',
        '\u00b4\u00b4'
    ]

    def __init__(self):
        """ Change Log

        Created:
            16-Sept-2022
            craigtrim@gmail.com
            *   handle post-processing
                https://github.com/craigtrim/spacy-token-parser/issues/2
            *   rename component
                https://github.com/craigtrim/spacy-token-parser/issues/3
        Updated:
            16-Sept-2022
            craigtrim@gmail.com
            *   add custom porter-stemmer
                https://github.com/craigtrim/datapipe-apis/issues/43
        """
        BaseObject.__init__(self, __name__)
        self._stem = PorterStemmer().stem

    def _normalize(self,
                   input_text: str) -> str:

        if type(input_text) != str:
            raise ValueError

        hyphens = [x for x in self.__hyphens if x in input_text]
        for hyphen in hyphens:
            input_text = input_text.replace(hyphen, '-')

        dquotes = [x for x in self.__dquotes if x in input_text]
        for dquote in dquotes:
            input_text = input_text.replace(dquote, '"')

        squotes = [x for x in self.__squotes if x in input_text]
        for squote in squotes:
            input_text = input_text.replace(squote, "'")

        return input_text.strip().lower()

    def process(self,
                tokens: list) -> list:

        for d_token in tokens:
            # ---------------------------------------------------------- ##
            # Update:       DO NOT use lemma as basis for 'normal' form
            # Reference:    https://github.com/craigtrim/spacy-token-parser/issues/2
            #               https://github.com/grafflr/graffl-core/issues/46#issuecomment-943708492
            # Old Code:     self._normalizer.input_text(token['lemma'])
            # ---------------------------------------------------------- ##
            d_token['normal'] = self._normalize(d_token['text'])

            if d_token['is_punct']:
                d_token['stem'] = d_token['normal']
            else:
                d_token['stem'] = str(
                    self._stem(d_token['normal']))
            del d_token['lemma']

        return tokens



#!/usr/bin/env python
# -*- coding: UTF-8 -*-
""" Extract Topics (with Anaphora Linking) """


from typing import List, Optional
from lingpatlab.baseblock import BaseObject
from lingpatlab.utils.dto import Sentences
from lingpatlab.analyze.dmo import TopicSequenceExtractor, PeopleSequenceAnalysis


class ExtractTopicEntities(BaseObject):
    """ Extract Topics (with Anaphora Linking) """

    def __init__(self,
                 ):
        """ Change Log

        Created:
            22-Mar-2024
            craigtrim@gmail.com
            *   based on 'extract-person-entities' in pursuit of
                https://github.com/craigtrim/datapipe-apis/issues/63
        """
        BaseObject.__init__(self, __name__)
        self._extract_topics = TopicSequenceExtractor().process
        self._analyze_topics = PeopleSequenceAnalysis().process

    def process(self,
                sentences: Sentences = None) -> Optional[List[str]]:
        """
        Process the given sentences and extract phrases based on the specified parameters.

        Args:
            sentences (Sentences): The sentences to be processed.

        Returns:
            Optional[List[str]]: A list of extracted phrases, or None if no phrases are found.
        """
        if not isinstance(sentences, Sentences):
            raise TypeError(type(sentences))

        exact_matches = set()
        fuzzy_matches = set()

        for sentence in sentences.sentences:

            dmoresult = self._extract_topics(sentence)

            [
                exact_matches.add(person)
                for person in dmoresult['exact']
            ]

            [
                fuzzy_matches.add(person)
                for person in dmoresult['fuzzy']
            ]

        if not exact_matches and not fuzzy_matches:
            return None

        exact_matches = sorted(exact_matches, reverse=True)
        fuzzy_matches = sorted(fuzzy_matches, reverse=True)

        topics = self._analyze_topics(
            exact_matches=exact_matches,
            fuzzy_matches=fuzzy_matches)

        return topics
